# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/sqs.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19ydb/core/protos/sqs.proto\x12\x0cNKikimr.NSQS\"%\n\x11TAuthentification\x12\x10\n\x08UserName\x18\x01 \x01(\t\"]\n\x0cTCredentials\x12\x14\n\nOAuthToken\x18\x01 \x01(\tH\x00\x12\x13\n\tTvmTicket\x18\x02 \x01(\tH\x00\x12\x15\n\x0bStaticCreds\x18\x03 \x01(\tH\x00\x42\x0b\n\tAccessKey\"\xc1\x01\n\x06TError\x12\x0e\n\x06Status\x18\x01 \x01(\r\x12\x0f\n\x07Message\x18\x02 \x01(\t\x12\x11\n\tErrorCode\x18\x04 \x01(\t\x12*\n\x05\x44\x65\x62ug\x18\x03 \x01(\x0b\x32\x1b.NKikimr.NSQS.TError.TDebug\x1aW\n\x06TDebug\x12\x1d\n\x15TransactionStatusCode\x18\x01 \x01(\r\x12\x15\n\rMiniKQLErrors\x18\x02 \x01(\x0c\x12\x17\n\x0f\x44\x61taShardErrors\x18\x03 \x01(\x0c\")\n\nTAttribute\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\r\n\x05Value\x18\x02 \x01(\x0c\"]\n\x11TMessageAttribute\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x10\n\x08\x44\x61taType\x18\x02 \x01(\t\x12\x13\n\x0bStringValue\x18\x03 \x01(\t\x12\x13\n\x0b\x42inaryValue\x18\x04 \x01(\x0c\"\xd2\x01\n\x1fTChangeMessageVisibilityRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12-\n\x04\x41uth\x18\x01 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\x12\x11\n\tQueueName\x18\x02 \x01(\t\x12\x15\n\rReceiptHandle\x18\x03 \x01(\x0c\x12\x19\n\x11VisibilityTimeout\x18\x04 \x01(\r\x12\n\n\x02Id\x18\x05 \x01(\t\"f\n TChangeMessageVisibilityResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\x12\n\n\x02Id\x18\x03 \x01(\t\"\xd9\x01\n$TChangeMessageVisibilityBatchRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12-\n\x04\x41uth\x18\x01 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\x12\x11\n\tQueueName\x18\x02 \x01(\t\x12>\n\x07\x45ntries\x18\x03 \x03(\x0b\x32-.NKikimr.NSQS.TChangeMessageVisibilityRequest\"\xa0\x01\n%TChangeMessageVisibilityBatchResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\x12?\n\x07\x45ntries\x18\x03 \x03(\x0b\x32..NKikimr.NSQS.TChangeMessageVisibilityResponse\"\x82\x03\n\x13TCreateQueueRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12-\n\x04\x41uth\x18\x01 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\x12\x11\n\tQueueName\x18\x02 \x01(\t\x12,\n\nAttributes\x18\x03 \x03(\x0b\x32\x18.NKikimr.NSQS.TAttribute\x12\x11\n\x06Shards\x18\x04 \x01(\x04:\x01\x34\x12\x15\n\nPartitions\x18\x05 \x01(\x04:\x01\x38\x12\x17\n\x0f\x45nableAutosplit\x18\x08 \x01(\x08\x12\x1f\n\x0bSizeToSplit\x18\t \x01(\x04:\n1073741824\x12\x33\n%EnableOutOfOrderTransactionsExecution\x18\x06 \x01(\x08:\x04true\x12\x17\n\x0f\x43ustomQueueName\x18\n \x01(\t\x12\x18\n\x10\x43reatedTimestamp\x18\x0b \x01(\x04\"s\n\x14TCreateQueueResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\x12\x11\n\tQueueName\x18\x03 \x01(\t\x12\x10\n\x08QueueUrl\x18\x04 \x01(\t\"\x86\x01\n\x12TCreateUserRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12-\n\x04\x41uth\x18\x01 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\x12\x10\n\x08UserName\x18\x02 \x01(\t\"M\n\x13TCreateUserResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\"\xaa\x01\n\x1aTGetQueueAttributesRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12-\n\x04\x41uth\x18\x01 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\x12\x11\n\tQueueName\x18\x02 \x01(\t\x12\r\n\x05Names\x18\x03 \x03(\t\x12\n\n\x02Id\x18\x04 \x01(\t\"\x8d\x04\n\x1bTGetQueueAttributesResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\x12\n\n\x02Id\x18\x0f \x01(\t\x12#\n\x1b\x41pproximateNumberOfMessages\x18\x03 \x01(\x04\x12*\n\"ApproximateNumberOfMessagesDelayed\x18\x04 \x01(\x04\x12-\n%ApproximateNumberOfMessagesNotVisible\x18\x05 \x01(\x04\x12\x18\n\x10\x43reatedTimestamp\x18\x06 \x01(\x04\x12\x14\n\x0c\x44\x65laySeconds\x18\x07 \x01(\x04\x12\x1d\n\x15LastModifiedTimestamp\x18\x08 \x01(\x04\x12\x1a\n\x12MaximumMessageSize\x18\t \x01(\x04\x12\x1e\n\x16MessageRetentionPeriod\x18\n \x01(\x04\x12%\n\x1dReceiveMessageWaitTimeSeconds\x18\x0b \x01(\x04\x12\x19\n\x11VisibilityTimeout\x18\x0c \x01(\x04\x12\x11\n\tFifoQueue\x18\r \x01(\x08\x12!\n\x19\x43ontentBasedDeduplication\x18\x0e \x01(\x08\x12\x15\n\rRedrivePolicy\x18\x10 \x01(\t\x12\x10\n\x08QueueArn\x18\x11 \x01(\t\"\xcb\x01\n\x1fTGetQueueAttributesBatchRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12-\n\x04\x41uth\x18\x01 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\x12\r\n\x05Names\x18\x03 \x03(\t\x12\x39\n\x07\x45ntries\x18\x04 \x03(\x0b\x32(.NKikimr.NSQS.TGetQueueAttributesRequest\"\x96\x01\n TGetQueueAttributesBatchResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\x12:\n\x07\x45ntries\x18\x03 \x03(\x0b\x32).NKikimr.NSQS.TGetQueueAttributesResponse\"\x88\x01\n\x13TGetQueueUrlRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12-\n\x04\x41uth\x18\x01 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\x12\x11\n\tQueueName\x18\x02 \x01(\t\"`\n\x14TGetQueueUrlResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\x12\x10\n\x08QueueUrl\x18\x03 \x01(\t\"\xad\x01\n\x15TDeleteMessageRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12-\n\x04\x41uth\x18\x01 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\x12\x11\n\tQueueName\x18\x02 \x01(\t\x12\x15\n\rReceiptHandle\x18\x03 \x01(\x0c\x12\n\n\x02Id\x18\x04 \x01(\t\"\\\n\x16TDeleteMessageResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\x12\n\n\x02Id\x18\x03 \x01(\t\"\xc5\x01\n\x1aTDeleteMessageBatchRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12-\n\x04\x41uth\x18\x01 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\x12\x11\n\tQueueName\x18\x02 \x01(\t\x12\x34\n\x07\x45ntries\x18\x03 \x03(\x0b\x32#.NKikimr.NSQS.TDeleteMessageRequest\"\x8c\x01\n\x1bTDeleteMessageBatchResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\x12\x35\n\x07\x45ntries\x18\x03 \x03(\x0b\x32$.NKikimr.NSQS.TDeleteMessageResponse\"\x94\x01\n\x13TDeleteQueueRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12-\n\x04\x41uth\x18\x01 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\x12\x11\n\tQueueName\x18\x02 \x01(\t\x12\n\n\x02Id\x18\x03 \x01(\t\"Z\n\x14TDeleteQueueResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\x12\n\n\x02Id\x18\x03 \x01(\t\"\xae\x01\n\x18TDeleteQueueBatchRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12-\n\x04\x41uth\x18\x01 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\x12\x32\n\x07\x45ntries\x18\x02 \x03(\x0b\x32!.NKikimr.NSQS.TDeleteQueueRequest\"\x88\x01\n\x19TDeleteQueueBatchResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\x12\x33\n\x07\x45ntries\x18\x03 \x03(\x0b\x32\".NKikimr.NSQS.TDeleteQueueResponse\"\x86\x01\n\x12TDeleteUserRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12-\n\x04\x41uth\x18\x01 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\x12\x10\n\x08UserName\x18\x02 \x01(\t\"M\n\x13TDeleteUserResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\"\x8d\x01\n\x12TListQueuesRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12-\n\x04\x41uth\x18\x01 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\x12\x17\n\x0fQueueNamePrefix\x18\x02 \x01(\t\"\xbe\x01\n\x13TListQueuesResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\x12<\n\x06Queues\x18\x03 \x03(\x0b\x32,.NKikimr.NSQS.TListQueuesResponse.TQueueType\x1a\x31\n\nTQueueType\x12\x11\n\tQueueName\x18\x01 \x01(\t\x12\x10\n\x08QueueUrl\x18\x02 \x01(\t\"\x8b\x01\n\x11TListUsersRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12-\n\x04\x41uth\x18\x01 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\x12\x16\n\x0eUserNamePrefix\x18\x02 \x01(\t\"_\n\x12TListUsersResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\x12\x11\n\tUserNames\x18\x03 \x03(\t\"\x93\x01\n\x12TPurgeQueueRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12-\n\x04\x41uth\x18\x01 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\x12\x11\n\tQueueName\x18\x02 \x01(\t\x12\n\n\x02Id\x18\x03 \x01(\t\"Y\n\x13TPurgeQueueResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x03 \x01(\t\x12\n\n\x02Id\x18\x04 \x01(\t\"\xac\x01\n\x17TPurgeQueueBatchRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12-\n\x04\x41uth\x18\x01 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\x12\x31\n\x07\x45ntries\x18\x02 \x03(\x0b\x32 .NKikimr.NSQS.TPurgeQueueRequest\"\x86\x01\n\x18TPurgeQueueBatchResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\x12\x32\n\x07\x45ntries\x18\x03 \x03(\x0b\x32!.NKikimr.NSQS.TPurgeQueueResponse\"\xb2\x02\n\x16TReceiveMessageRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12-\n\x04\x41uth\x18\x01 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\x12\x11\n\tQueueName\x18\x02 \x01(\t\x12\x1b\n\x13MaxNumberOfMessages\x18\x03 \x01(\r\x12\x1f\n\x17ReceiveRequestAttemptId\x18\x04 \x01(\t\x12\x19\n\x11VisibilityTimeout\x18\x05 \x01(\r\x12\x17\n\x0fWaitTimeSeconds\x18\x06 \x01(\r\x12\x15\n\rAttributeName\x18\x07 \x03(\t\x12\x1c\n\x14MessageAttributeName\x18\x08 \x03(\t\"\xb3\x04\n\x17TReceiveMessageResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\x12@\n\x08Messages\x18\x03 \x03(\x0b\x32..NKikimr.NSQS.TReceiveMessageResponse.TMessage\x12\x1f\n\x17ReceiveRequestAttemptId\x18\x04 \x01(\t\x1a\xfc\x02\n\x08TMessage\x12(\n ApproximateFirstReceiveTimestamp\x18\x01 \x01(\x04\x12\x1f\n\x17\x41pproximateReceiveCount\x18\x02 \x01(\x04\x12\x11\n\tMessageId\x18\x03 \x01(\t\x12\x1e\n\x16MessageDeduplicationId\x18\x04 \x01(\t\x12\x16\n\x0eMessageGroupId\x18\x05 \x01(\t\x12\x18\n\x10MD5OfMessageBody\x18\x06 \x01(\t\x12\x1e\n\x16MD5OfMessageAttributes\x18\x0c \x01(\t\x12:\n\x11MessageAttributes\x18\x07 \x03(\x0b\x32\x1f.NKikimr.NSQS.TMessageAttribute\x12\x0c\n\x04\x44\x61ta\x18\x08 \x01(\x0c\x12\x15\n\rReceiptHandle\x18\t \x01(\x0c\x12\x15\n\rSentTimestamp\x18\n \x01(\x04\x12\x16\n\x0eSequenceNumber\x18\x0b \x01(\x04\x12\x10\n\x08SenderId\x18\r \x01(\t\"\xb3\x02\n\x13TSendMessageRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12-\n\x04\x41uth\x18\x01 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\x12\x11\n\tQueueName\x18\x02 \x01(\t\x12\x16\n\x0eMessageGroupId\x18\x03 \x01(\t\x12\x1e\n\x16MessageDeduplicationId\x18\x04 \x01(\t\x12\x13\n\x0bMessageBody\x18\x05 \x01(\x0c\x12:\n\x11MessageAttributes\x18\x06 \x03(\x0b\x32\x1f.NKikimr.NSQS.TMessageAttribute\x12\n\n\x02Id\x18\x07 \x01(\t\x12\x14\n\x0c\x44\x65laySeconds\x18\x08 \x01(\x04\"\xbf\x01\n\x14TSendMessageResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\x12\x1e\n\x16MD5OfMessageAttributes\x18\x03 \x01(\t\x12\x18\n\x10MD5OfMessageBody\x18\x04 \x01(\t\x12\x11\n\tMessageId\x18\x05 \x01(\t\x12\x16\n\x0eSequenceNumber\x18\x06 \x01(\x04\x12\n\n\x02Id\x18\x07 \x01(\t\"\xc1\x01\n\x18TSendMessageBatchRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12-\n\x04\x41uth\x18\x01 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\x12\x11\n\tQueueName\x18\x02 \x01(\t\x12\x32\n\x07\x45ntries\x18\x03 \x03(\x0b\x32!.NKikimr.NSQS.TSendMessageRequest\"\x88\x01\n\x19TSendMessageBatchResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\x12\x33\n\x07\x45ntries\x18\x03 \x03(\x0b\x32\".NKikimr.NSQS.TSendMessageResponse\"\xbd\x01\n\x1aTSetQueueAttributesRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12-\n\x04\x41uth\x18\x01 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\x12\x11\n\tQueueName\x18\x02 \x01(\t\x12,\n\nAttributes\x18\x03 \x03(\x0b\x32\x18.NKikimr.NSQS.TAttribute\"U\n\x1bTSetQueueAttributesResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\"8\n\x0cTPermissions\x12\x0f\n\x07Subject\x18\x01 \x01(\t\x12\x17\n\x0fPermissionNames\x18\x02 \x03(\t\"\xa4\x01\n\x12TPermissionsAction\x12+\n\x05Grant\x18\x01 \x01(\x0b\x32\x1a.NKikimr.NSQS.TPermissionsH\x00\x12,\n\x06Revoke\x18\x02 \x01(\x0b\x32\x1a.NKikimr.NSQS.TPermissionsH\x00\x12)\n\x03Set\x18\x03 \x01(\x0b\x32\x1a.NKikimr.NSQS.TPermissionsH\x00\x42\x08\n\x06\x41\x63tion\"\xd9\x01\n\x19TModifyPermissionsRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12\x10\n\x08Resource\x18\x01 \x01(\t\x12\x31\n\x07\x41\x63tions\x18\x02 \x03(\x0b\x32 .NKikimr.NSQS.TPermissionsAction\x12\x17\n\x08\x43learACL\x18\x03 \x01(\x08:\x05\x66\x61lse\x12-\n\x04\x41uth\x18\x04 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\"T\n\x1aTModifyPermissionsResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\"\x87\x01\n\x17TListPermissionsRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12-\n\x04\x41uth\x18\x02 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\"~\n\x11TQueuePermissions\x12/\n\x0bPermissions\x18\x01 \x03(\x0b\x32\x1a.NKikimr.NSQS.TPermissions\x12\x38\n\x14\x45\x66\x66\x65\x63tivePermissions\x18\x02 \x03(\x0b\x32\x1a.NKikimr.NSQS.TPermissions\"\x80\x01\n\x13TAccountPermissions\x12/\n\x0bPermissions\x18\x01 \x03(\x0b\x32\x1a.NKikimr.NSQS.TPermissions\x12\x38\n\x14\x45\x66\x66\x65\x63tivePermissions\x18\x02 \x03(\x0b\x32\x1a.NKikimr.NSQS.TPermissions\"\x82\x01\n\x15TDirectoryPermissions\x12/\n\x0bPermissions\x18\x01 \x03(\x0b\x32\x1a.NKikimr.NSQS.TPermissions\x12\x38\n\x14\x45\x66\x66\x65\x63tivePermissions\x18\x02 \x03(\x0b\x32\x1a.NKikimr.NSQS.TPermissions\"\x9b\x02\n\x18TListPermissionsResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\x12;\n\x10QueuePermissions\x18\x03 \x01(\x0b\x32\x1f.NKikimr.NSQS.TQueuePermissionsH\x00\x12=\n\x12\x41\x63\x63ountPermissions\x18\x04 \x01(\x0b\x32\x1f.NKikimr.NSQS.TQueuePermissionsH\x00\x12?\n\x14\x44irectoryPermissions\x18\x05 \x01(\x0b\x32\x1f.NKikimr.NSQS.TQueuePermissionsH\x00\x42\n\n\x08NodeType\"\x97\x01\n\"TListDeadLetterSourceQueuesRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12\x11\n\tQueueName\x18\x01 \x01(\t\x12-\n\x04\x41uth\x18\x02 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\"\xde\x01\n#TListDeadLetterSourceQueuesResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\x12L\n\x06Queues\x18\x03 \x03(\x0b\x32<.NKikimr.NSQS.TListDeadLetterSourceQueuesResponse.TQueueType\x1a\x31\n\nTQueueType\x12\x11\n\tQueueName\x18\x01 \x01(\t\x12\x10\n\x08QueueUrl\x18\x02 \x01(\t\"u\n\x13TCountQueuesRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12-\n\x04\x41uth\x18\x01 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\"]\n\x14TCountQueuesResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\x12\r\n\x05\x43ount\x18\x03 \x01(\x04')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.sqs_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TAUTHENTIFICATION._serialized_start=43
  _TAUTHENTIFICATION._serialized_end=80
  _TCREDENTIALS._serialized_start=82
  _TCREDENTIALS._serialized_end=175
  _TERROR._serialized_start=178
  _TERROR._serialized_end=371
  _TERROR_TDEBUG._serialized_start=284
  _TERROR_TDEBUG._serialized_end=371
  _TATTRIBUTE._serialized_start=373
  _TATTRIBUTE._serialized_end=414
  _TMESSAGEATTRIBUTE._serialized_start=416
  _TMESSAGEATTRIBUTE._serialized_end=509
  _TCHANGEMESSAGEVISIBILITYREQUEST._serialized_start=512
  _TCHANGEMESSAGEVISIBILITYREQUEST._serialized_end=722
  _TCHANGEMESSAGEVISIBILITYRESPONSE._serialized_start=724
  _TCHANGEMESSAGEVISIBILITYRESPONSE._serialized_end=826
  _TCHANGEMESSAGEVISIBILITYBATCHREQUEST._serialized_start=829
  _TCHANGEMESSAGEVISIBILITYBATCHREQUEST._serialized_end=1046
  _TCHANGEMESSAGEVISIBILITYBATCHRESPONSE._serialized_start=1049
  _TCHANGEMESSAGEVISIBILITYBATCHRESPONSE._serialized_end=1209
  _TCREATEQUEUEREQUEST._serialized_start=1212
  _TCREATEQUEUEREQUEST._serialized_end=1598
  _TCREATEQUEUERESPONSE._serialized_start=1600
  _TCREATEQUEUERESPONSE._serialized_end=1715
  _TCREATEUSERREQUEST._serialized_start=1718
  _TCREATEUSERREQUEST._serialized_end=1852
  _TCREATEUSERRESPONSE._serialized_start=1854
  _TCREATEUSERRESPONSE._serialized_end=1931
  _TGETQUEUEATTRIBUTESREQUEST._serialized_start=1934
  _TGETQUEUEATTRIBUTESREQUEST._serialized_end=2104
  _TGETQUEUEATTRIBUTESRESPONSE._serialized_start=2107
  _TGETQUEUEATTRIBUTESRESPONSE._serialized_end=2632
  _TGETQUEUEATTRIBUTESBATCHREQUEST._serialized_start=2635
  _TGETQUEUEATTRIBUTESBATCHREQUEST._serialized_end=2838
  _TGETQUEUEATTRIBUTESBATCHRESPONSE._serialized_start=2841
  _TGETQUEUEATTRIBUTESBATCHRESPONSE._serialized_end=2991
  _TGETQUEUEURLREQUEST._serialized_start=2994
  _TGETQUEUEURLREQUEST._serialized_end=3130
  _TGETQUEUEURLRESPONSE._serialized_start=3132
  _TGETQUEUEURLRESPONSE._serialized_end=3228
  _TDELETEMESSAGEREQUEST._serialized_start=3231
  _TDELETEMESSAGEREQUEST._serialized_end=3404
  _TDELETEMESSAGERESPONSE._serialized_start=3406
  _TDELETEMESSAGERESPONSE._serialized_end=3498
  _TDELETEMESSAGEBATCHREQUEST._serialized_start=3501
  _TDELETEMESSAGEBATCHREQUEST._serialized_end=3698
  _TDELETEMESSAGEBATCHRESPONSE._serialized_start=3701
  _TDELETEMESSAGEBATCHRESPONSE._serialized_end=3841
  _TDELETEQUEUEREQUEST._serialized_start=3844
  _TDELETEQUEUEREQUEST._serialized_end=3992
  _TDELETEQUEUERESPONSE._serialized_start=3994
  _TDELETEQUEUERESPONSE._serialized_end=4084
  _TDELETEQUEUEBATCHREQUEST._serialized_start=4087
  _TDELETEQUEUEBATCHREQUEST._serialized_end=4261
  _TDELETEQUEUEBATCHRESPONSE._serialized_start=4264
  _TDELETEQUEUEBATCHRESPONSE._serialized_end=4400
  _TDELETEUSERREQUEST._serialized_start=4403
  _TDELETEUSERREQUEST._serialized_end=4537
  _TDELETEUSERRESPONSE._serialized_start=4539
  _TDELETEUSERRESPONSE._serialized_end=4616
  _TLISTQUEUESREQUEST._serialized_start=4619
  _TLISTQUEUESREQUEST._serialized_end=4760
  _TLISTQUEUESRESPONSE._serialized_start=4763
  _TLISTQUEUESRESPONSE._serialized_end=4953
  _TLISTQUEUESRESPONSE_TQUEUETYPE._serialized_start=4904
  _TLISTQUEUESRESPONSE_TQUEUETYPE._serialized_end=4953
  _TLISTUSERSREQUEST._serialized_start=4956
  _TLISTUSERSREQUEST._serialized_end=5095
  _TLISTUSERSRESPONSE._serialized_start=5097
  _TLISTUSERSRESPONSE._serialized_end=5192
  _TPURGEQUEUEREQUEST._serialized_start=5195
  _TPURGEQUEUEREQUEST._serialized_end=5342
  _TPURGEQUEUERESPONSE._serialized_start=5344
  _TPURGEQUEUERESPONSE._serialized_end=5433
  _TPURGEQUEUEBATCHREQUEST._serialized_start=5436
  _TPURGEQUEUEBATCHREQUEST._serialized_end=5608
  _TPURGEQUEUEBATCHRESPONSE._serialized_start=5611
  _TPURGEQUEUEBATCHRESPONSE._serialized_end=5745
  _TRECEIVEMESSAGEREQUEST._serialized_start=5748
  _TRECEIVEMESSAGEREQUEST._serialized_end=6054
  _TRECEIVEMESSAGERESPONSE._serialized_start=6057
  _TRECEIVEMESSAGERESPONSE._serialized_end=6620
  _TRECEIVEMESSAGERESPONSE_TMESSAGE._serialized_start=6240
  _TRECEIVEMESSAGERESPONSE_TMESSAGE._serialized_end=6620
  _TSENDMESSAGEREQUEST._serialized_start=6623
  _TSENDMESSAGEREQUEST._serialized_end=6930
  _TSENDMESSAGERESPONSE._serialized_start=6933
  _TSENDMESSAGERESPONSE._serialized_end=7124
  _TSENDMESSAGEBATCHREQUEST._serialized_start=7127
  _TSENDMESSAGEBATCHREQUEST._serialized_end=7320
  _TSENDMESSAGEBATCHRESPONSE._serialized_start=7323
  _TSENDMESSAGEBATCHRESPONSE._serialized_end=7459
  _TSETQUEUEATTRIBUTESREQUEST._serialized_start=7462
  _TSETQUEUEATTRIBUTESREQUEST._serialized_end=7651
  _TSETQUEUEATTRIBUTESRESPONSE._serialized_start=7653
  _TSETQUEUEATTRIBUTESRESPONSE._serialized_end=7738
  _TPERMISSIONS._serialized_start=7740
  _TPERMISSIONS._serialized_end=7796
  _TPERMISSIONSACTION._serialized_start=7799
  _TPERMISSIONSACTION._serialized_end=7963
  _TMODIFYPERMISSIONSREQUEST._serialized_start=7966
  _TMODIFYPERMISSIONSREQUEST._serialized_end=8183
  _TMODIFYPERMISSIONSRESPONSE._serialized_start=8185
  _TMODIFYPERMISSIONSRESPONSE._serialized_end=8269
  _TLISTPERMISSIONSREQUEST._serialized_start=8272
  _TLISTPERMISSIONSREQUEST._serialized_end=8407
  _TQUEUEPERMISSIONS._serialized_start=8409
  _TQUEUEPERMISSIONS._serialized_end=8535
  _TACCOUNTPERMISSIONS._serialized_start=8538
  _TACCOUNTPERMISSIONS._serialized_end=8666
  _TDIRECTORYPERMISSIONS._serialized_start=8669
  _TDIRECTORYPERMISSIONS._serialized_end=8799
  _TLISTPERMISSIONSRESPONSE._serialized_start=8802
  _TLISTPERMISSIONSRESPONSE._serialized_end=9085
  _TLISTDEADLETTERSOURCEQUEUESREQUEST._serialized_start=9088
  _TLISTDEADLETTERSOURCEQUEUESREQUEST._serialized_end=9239
  _TLISTDEADLETTERSOURCEQUEUESRESPONSE._serialized_start=9242
  _TLISTDEADLETTERSOURCEQUEUESRESPONSE._serialized_end=9464
  _TLISTDEADLETTERSOURCEQUEUESRESPONSE_TQUEUETYPE._serialized_start=4904
  _TLISTDEADLETTERSOURCEQUEUESRESPONSE_TQUEUETYPE._serialized_end=4953
  _TCOUNTQUEUESREQUEST._serialized_start=9466
  _TCOUNTQUEUESREQUEST._serialized_end=9583
  _TCOUNTQUEUESRESPONSE._serialized_start=9585
  _TCOUNTQUEUESRESPONSE._serialized_end=9678
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/index_builder.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.public.api.protos import ydb_issue_message_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__issue__message__pb2
from ydb.public.api.protos import ydb_operation_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__operation__pb2
from ydb.public.api.protos import ydb_status_codes_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__status__codes__pb2
from ydb.public.api.protos import ydb_table_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__table__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#ydb/core/protos/index_builder.proto\x12\x13NKikimrIndexBuilder\x1a-ydb/public/api/protos/ydb_issue_message.proto\x1a)ydb/public/api/protos/ydb_operation.proto\x1a,ydb/public/api/protos/ydb_status_codes.proto\x1a%ydb/public/api/protos/ydb_table.proto\"\xd7\x01\n\x13TIndexBuildSettings\x12\x13\n\x0bsource_path\x18\x01 \x01(\t\x12$\n\x05index\x18\x02 \x01(\x0b\x32\x15.Ydb.Table.TableIndex\x12\x1b\n\x0emax_batch_rows\x18\x03 \x01(\r:\x03\x35\x30\x30\x12 \n\x0fmax_batch_bytes\x18\x04 \x01(\x04:\x07\x38\x33\x38\x38\x36\x30\x38\x12 \n\x14max_shards_in_flight\x18\x05 \x01(\r:\x02\x33\x32\x12$\n\x18max_retries_upload_batch\x18\x06 \x01(\r:\x02\x35\x30\"\xc4\x01\n\x0bTIndexBuild\x12\n\n\x02Id\x18\x01 \x01(\x04\x12\'\n\x06Issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12/\n\x05State\x18\x03 \x01(\x0e\x32 .Ydb.Table.IndexBuildState.State\x12:\n\x08Settings\x18\x04 \x01(\x0b\x32(.NKikimrIndexBuilder.TIndexBuildSettings\x12\x13\n\x08Progress\x18\x05 \x01(\x02:\x01\x30\"\xac\x01\n\x10TEvCreateRequest\x12\x38\n\x0fOperationParams\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04TxId\x18\x02 \x01(\x04\x12\x14\n\x0c\x44\x61tabaseName\x18\x03 \x01(\t\x12:\n\x08Settings\x18\x04 \x01(\x0b\x32(.NKikimrIndexBuilder.TIndexBuildSettings\"\xab\x01\n\x11TEvCreateResponse\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12)\n\x06Status\x18\x02 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x03 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x34\n\nIndexBuild\x18\x04 \x01(\x0b\x32 .NKikimrIndexBuilder.TIndexBuild\";\n\rTEvGetRequest\x12\x14\n\x0c\x44\x61tabaseName\x18\x01 \x01(\t\x12\x14\n\x0cIndexBuildId\x18\x02 \x01(\x04\"\x9a\x01\n\x0eTEvGetResponse\x12)\n\x06Status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x34\n\nIndexBuild\x18\x03 \x01(\x0b\x32 .NKikimrIndexBuilder.TIndexBuild\"L\n\x10TEvCancelRequest\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x14\n\x0c\x44\x61tabaseName\x18\x02 \x01(\t\x12\x14\n\x0cIndexBuildId\x18\x03 \x01(\x04\"u\n\x11TEvCancelResponse\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12)\n\x06Status\x18\x02 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x03 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\"L\n\x10TEvForgetRequest\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x14\n\x0c\x44\x61tabaseName\x18\x02 \x01(\t\x12\x14\n\x0cIndexBuildId\x18\x03 \x01(\x04\"u\n\x11TEvForgetResponse\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12)\n\x06Status\x18\x02 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x03 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\"K\n\x0eTEvListRequest\x12\x14\n\x0c\x44\x61tabaseName\x18\x01 \x01(\t\x12\x10\n\x08PageSize\x18\x02 \x01(\x04\x12\x11\n\tPageToken\x18\x03 \x01(\t\"\xaf\x01\n\x0fTEvListResponse\x12)\n\x06Status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x31\n\x07\x45ntries\x18\x03 \x03(\x0b\x32 .NKikimrIndexBuilder.TIndexBuild\x12\x15\n\rNextPageToken\x18\x04 \x01(\tB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.index_builder_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TINDEXBUILDSETTINGS._serialized_start=236
  _TINDEXBUILDSETTINGS._serialized_end=451
  _TINDEXBUILD._serialized_start=454
  _TINDEXBUILD._serialized_end=650
  _TEVCREATEREQUEST._serialized_start=653
  _TEVCREATEREQUEST._serialized_end=825
  _TEVCREATERESPONSE._serialized_start=828
  _TEVCREATERESPONSE._serialized_end=999
  _TEVGETREQUEST._serialized_start=1001
  _TEVGETREQUEST._serialized_end=1060
  _TEVGETRESPONSE._serialized_start=1063
  _TEVGETRESPONSE._serialized_end=1217
  _TEVCANCELREQUEST._serialized_start=1219
  _TEVCANCELREQUEST._serialized_end=1295
  _TEVCANCELRESPONSE._serialized_start=1297
  _TEVCANCELRESPONSE._serialized_end=1414
  _TEVFORGETREQUEST._serialized_start=1416
  _TEVFORGETREQUEST._serialized_end=1492
  _TEVFORGETRESPONSE._serialized_start=1494
  _TEVFORGETRESPONSE._serialized_end=1611
  _TEVLISTREQUEST._serialized_start=1613
  _TEVLISTREQUEST._serialized_end=1688
  _TEVLISTRESPONSE._serialized_start=1691
  _TEVLISTRESPONSE._serialized_end=1866
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/tablet_counters_aggregator.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0ydb/core/protos/tablet_counters_aggregator.proto\x12\x1fNKikimrTabletCountersAggregator\"E\n\x0fTTabletCounters\x12\x16\n\x0eSimpleCounters\x18\x01 \x03(\x04\x12\x1a\n\x12\x43umulativeCounters\x18\x02 \x03(\x04\"\xba\x01\n\x13TTabletCountersInfo\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12J\n\x10\x45xecutorCounters\x18\x02 \x01(\x0b\x32\x30.NKikimrTabletCountersAggregator.TTabletCounters\x12\x45\n\x0b\x41ppCounters\x18\x03 \x01(\x0b\x32\x30.NKikimrTabletCountersAggregator.TTabletCounters\"-\n\x18TEvTabletCountersRequest\x12\x11\n\tTabletIds\x18\x01 \x03(\x04\"g\n\x19TEvTabletCountersResponse\x12J\n\x0c\x43ountersInfo\x18\x01 \x03(\x0b\x32\x34.NKikimrTabletCountersAggregator.TTabletCountersInfoB\x1b\n\x16ru.yandex.kikimr.proto\xf8\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.tablet_counters_aggregator_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\370\001\001'
  _TTABLETCOUNTERS._serialized_start=85
  _TTABLETCOUNTERS._serialized_end=154
  _TTABLETCOUNTERSINFO._serialized_start=157
  _TTABLETCOUNTERSINFO._serialized_end=343
  _TEVTABLETCOUNTERSREQUEST._serialized_start=345
  _TEVTABLETCOUNTERSREQUEST._serialized_end=390
  _TEVTABLETCOUNTERSRESPONSE._serialized_start=392
  _TEVTABLETCOUNTERSRESPONSE._serialized_end=495
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/mon.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19ydb/core/protos/mon.proto\x12\x0fNKikimrMonProto\":\n\tTSockAddr\x12\x0e\n\x06\x46\x61mily\x18\x01 \x01(\r\x12\x0f\n\x07\x41\x64\x64ress\x18\x02 \x01(\t\x12\x0c\n\x04Port\x18\x03 \x01(\r\"X\n\x14TEvMonitoringRequest\x12\x13\n\x0bHttpRequest\x18\x01 \x01(\t\x12+\n\x07\x41\x64\x64ress\x18\x02 \x01(\x0b\x32\x1a.NKikimrMonProto.TSockAddr\"-\n\x15TEvMonitoringResponse\x12\x14\n\x0cHttpResponse\x18\x01 \x01(\t')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.mon_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TSOCKADDR._serialized_start=46
  _TSOCKADDR._serialized_end=104
  _TEVMONITORINGREQUEST._serialized_start=106
  _TEVMONITORINGREQUEST._serialized_end=194
  _TEVMONITORINGRESPONSE._serialized_start=196
  _TEVMONITORINGRESPONSE._serialized_end=241
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/services.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eydb/core/protos/services.proto\x12\x0fNKikimrServices\"\x87\x85\x01\n\tTActivity\"\xf8\x84\x01\n\x05\x45Type\x12\t\n\x05OTHER\x10\x00\x12\x10\n\x0c\x41\x43TOR_SYSTEM\x10\x01\x12\x13\n\x0f\x41\x43TORLIB_COMMON\x10\x02\x12\x12\n\x0e\x41\x43TORLIB_STATS\x10\x03\x12\r\n\tLOG_ACTOR\x10\x04\x12\x17\n\x13\x41\x43TORLIB_LONG_TIMER\x10\x05\x12\x10\n\x0cTX_REQ_PROXY\x10\x06\x12\x14\n\x10VDISK_COMPACTION\x10\x07\x12\x12\n\x0eTX_PROXY_ACTOR\x10\x08\x12\x16\n\x12TX_ALLOCATOR_ACTOR\x10\t\x12\x18\n\x14TX_COORDINATOR_ACTOR\x10\n\x12\x15\n\x11TX_MEDIATOR_ACTOR\x10\x0b\x12\x1a\n\x16INTERCONNECT_PROXY_TCP\x10\x0c\x12\x1c\n\x18INTERCONNECT_SESSION_TCP\x10\r\x12\x16\n\x12\x42S_PROXY_PUT_ACTOR\x10\x0e\x12\x16\n\x12TX_DATASHARD_ACTOR\x10\x0f\x12\x16\n\x12TABLET_PIPE_CLIENT\x10\x10\x12\x16\n\x12TABLET_PIPE_SERVER\x10\x11\x12\x16\n\x12MSGBUS_PROXY_ACTOR\x10\x12\x12\x12\n\x0eVDISK_SKELETON\x10\x13\x12\x16\n\x12PROXY_SCHEME_CACHE\x10\x14\x12\x0f\n\x0bPDISK_ACTOR\x10\x15\x12\x16\n\x12\x42S_PROXY_GET_ACTOR\x10\x16\x12\x12\n\x0e\x42S_PROXY_ACTOR\x10\x17\x12\x18\n\x14\x42S_HULLCOMP_SELECTOR\x10\x18\x12\x18\n\x14TABLET_REQ_WRITE_LOG\x10\x19\x12\x1c\n\x18\x42S_HULL_HUGE_BLOB_WRITER\x10\x1a\x12 \n\x1c\x42S_HULL_HUGE_BLOB_CHUNKALLOC\x10\x1b\x12\"\n\x1e\x42S_HULL_HUGE_BLOB_CHUNKDESTROY\x10\x1c\x12%\n!BS_HULL_HUGE_BLOB_ENTRYPOINTSAVER\x10\x1d\x12\x17\n\x13\x42S_HULL_HUGE_KEEPER\x10\x1e\x12\x15\n\x11\x42S_HULL_SYNC_FULL\x10\x1f\x12\x18\n\x14\x42S_DB_LOCAL_RECOVERY\x10 \x12\x1a\n\x16\x42S_RECOVERY_LOG_CUTTER\x10!\x12\x1a\n\x16\x42S_RECOVERY_LOG_WRITER\x10\"\x12\x10\n\x0c\x42S_MON_ERROR\x10#\x12\x17\n\x13\x42S_MON_HIST_UPDATER\x10$\x12\x14\n\x10\x42S_MON_MAIN_PAGE\x10%\x12\x17\n\x13\x42S_MON_SF_LOGOBLOBS\x10&\x12\x16\n\x12\x42S_MON_SF_BARRIERS\x10\'\x12\x14\n\x10\x42S_MON_SF_LBSTAT\x10(\x12\x17\n\x13\x42S_MON_SF_MAIN_PAGE\x10)\x12\x1a\n\x16\x42S_ASYNC_LSN_COMMITTER\x10*\x12\x1c\n\x18\x42S_ASYNC_FRESH_COMMITTER\x10+\x12\x1c\n\x18\x42S_ASYNC_LEVEL_COMMITTER\x10,\x12\x18\n\x14\x42S_ASYNC_LEVEL_INDEX\x10-\x12\x1b\n\x17\x42S_LEVEL_SEGMENT_LOADER\x10.\x12\x1f\n\x1b\x42S_ORD_LEVEL_SEGMENT_LOADER\x10/\x12!\n\x1d\x42S_UNORD_LEVEL_SEGMENT_LOADER\x10\x30\x12\x19\n\x15\x42S_LEVEL_INDEX_LOADER\x10\x31\x12\x0c\n\x08\x42S_VDISK\x10\x32\x12\x18\n\x14\x42S_SYNCLOG_COMMITTER\x10\x33\x12\x15\n\x11\x42S_SYNCLOG_KEEPER\x10\x34\x12\x1a\n\x16\x42S_LEVEL_INDEX_BARRIER\x10\x35\x12!\n\x1d\x42S_HULLQUERY_RANGE_INDEX_ONLY\x10\x36\x12\x1b\n\x17\x42S_HULLQUERY_RANGE_DATA\x10\x37\x12\x13\n\x0f\x42S_READ_BATCHER\x10\x38\x12\x1d\n\x19\x42S_LEVEL_INDEX_STAT_QUERY\x10\x39\x12\x14\n\x10\x42S_HULL_REPL_JOB\x10:\x12\x12\n\x0e\x42S_PDISK_ACTOR\x10;\x12\x12\n\x0e\x42S_GROUP_BLOCK\x10<\x12\x1c\n\x18\x42S_GROUP_COLLECT_GARBAGE\x10=\x12\x15\n\x11\x42S_GROUP_DISCOVER\x10>\x12\x12\n\x0e\x42S_GROUP_RANGE\x10?\x12\x16\n\x12\x42S_GROUP_PROXY_MON\x10@\x12\x15\n\x11\x42S_REPL_SCHEDULER\x10\x41\x12\x1c\n\x18\x42S_HANDOFF_SYNCLOG_PROXY\x10\x42\x12\x17\n\x13\x42S_VDISK_REPL_PROXY\x10\x43\x12\x18\n\x14\x42S_SYNC_FULL_HANDLER\x10\x44\x12\x14\n\x10\x42S_SKELETON_BACK\x10\x45\x12\x15\n\x11\x42S_SKELETON_FRONT\x10\x46\x12\x1d\n\x19\x42S_STATUS_REQUEST_HANDLER\x10G\x12\x11\n\rBS_SYNCER_JOB\x10H\x12\x17\n\x13\x42S_SYNCER_COMMITTER\x10I\x12\x17\n\x13\x42S_SYNCER_SCHEDULER\x10J\x12\x1b\n\x17\x42S_SYNCLOG_LOCAL_STATUS\x10K\x12\x17\n\x13\x42S_SYNCLOG_HTTPINFO\x10L\x12\x15\n\x11\x42S_SYNCLOG_READER\x10M\x12\x14\n\x10\x42S_SYNCLOG_ACTOR\x10N\x12\x14\n\x10\x42S_HANDOFF_PROXY\x10O\x12\x1a\n\x16\x42S_HANDOFF_MON_REQUEST\x10P\x12\x12\n\x0e\x42S_HANDOFF_MON\x10Q\x12\x1d\n\x19\x42S_HULL_LOG_CUTTER_NOTIFY\x10R\x12\x17\n\x13SS_REPLICA_GUARDIAN\x10S\x12\x16\n\x12SS_TABLET_GUARDIAN\x10T\x12\n\n\x06SS_MON\x10U\x12\x14\n\x10SS_PROXY_REQUEST\x10V\x12\x0c\n\x08SS_PROXY\x10W\x12\x11\n\rSS_PROXY_STUB\x10X\x12\x0e\n\nSS_REPLICA\x10Y\x12\"\n\x1eTX_COORDINATOR_MEDIATORQ_ACTOR\x10Z\x12\x19\n\x15TABLET_EXECUTOR_ACTOR\x10[\x12\x16\n\x12TX_PROXY_SCHEMEREQ\x10\\\x12\x18\n\x14TX_PROXY_SCHEMECACHE\x10]\x12\x1b\n\x17TABLET_FORWARDING_ACTOR\x10^\x12\x1b\n\x17TABLET_MONITORING_PROXY\x10_\x12\x19\n\x15TABLET_RESOLVER_ACTOR\x10`\x12\x1c\n\x18TABLET_REQ_REBUILD_GRAPH\x10\x61\x12\x1a\n\x16TABLET_REQ_FIND_LATEST\x10\x62\x12\x17\n\x13TABLET_REQ_BLOCK_BS\x10\x63\x12\x1e\n\x1aTABLET_COUNTERS_AGGREGATOR\x10\x64\x12\x10\n\x0cTABLET_ACTOR\x10\x65\x12\x17\n\x13TABLET_LOCGR_LOADER\x10\x66\x12\r\n\tTABLET_GC\x10g\x12\x1c\n\x18TABLET_COMPACTION_BROKER\x10h\x12\x19\n\x15TABLET_GET_THROTTLING\x10i\x12\x15\n\x11TX_PROXY_NAVIGATE\x10j\x12\x15\n\x11TABLET_OPS_HOST_A\x10k\x12\x11\n\rOPS_COMPACT_A\x10l\x12\x10\n\x0cOPS_BACKUP_A\x10m\x12\x1e\n\x1aTABLET_INMEM_STATE_CLEANUP\x10n\x12\x1b\n\x17MINIKQL_COMPILE_SERVICE\x10o\x12\x19\n\x15MINIKQL_COMPILE_ACTOR\x10p\x12\x1e\n\x1a\x43LIENT_SCHEME_CACHE_LOOKUP\x10q\x12$\n CLIENT_SCHEME_CACHE_LOOKUP_BATCH\x10r\x12#\n\x1f\x43LIENT_SCHEME_CACHE_LOOKUP_TREE\x10s\x12\x1e\n\x1a\x43LIENT_SCHEME_CACHE_ONLINE\x10t\x12\x12\n\x0eKEYVALUE_ACTOR\x10u\x12\x17\n\x13MSGBUS_TRACER_ACTOR\x10v\x12\x1b\n\x17NODE_WHITEBOARD_SERVICE\x10w\x12\x0f\n\x0b\x43MS_SERVICE\x10x\x12\x15\n\x11\x43MS_SERVICE_PROXY\x10y\x12\x15\n\x11NODE_BROKER_ACTOR\x10z\x12\x16\n\x12RTMR_CACHE_SERVICE\x10{\x12!\n\x1dRTMR_CACHE_SERVICE_READ_QUEUE\x10|\x12#\n\x1fRTMR_CACHE_SERVICE_TABLET_QUEUE\x10}\x12\x1d\n\x19RTMR_CACHE_SERVICE_WRITER\x10~\x12\"\n\x1eRTMR_CACHE_SERVICE_WRITE_QUEUE\x10\x7f\x12\x1c\n\x17RTMR_COMPACTION_SERVICE\x10\x80\x01\x12\x1c\n\x17RTMR_MONITORING_SERVICE\x10\x81\x01\x12\x10\n\x0bRTMR_TABLET\x10\x82\x01\x12\x1d\n\x18RTMR_TABLET_BOOTSTRAPPER\x10\x83\x01\x12\x19\n\x14RTMR_TABLET_EXECUTOR\x10\x84\x01\x12!\n\x1cRTMR_TABLET_EXECUTOR_CLEANUP\x10\x85\x01\x12$\n\x1fRTMR_TABLET_EXECUTOR_COMPACTION\x10\x86\x01\x12\x1f\n\x1aRTMR_TABLET_EXECUTOR_FLUSH\x10\x87\x01\x12\x1e\n\x19RTMR_TABLET_EXECUTOR_INIT\x10\x88\x01\x12\x1e\n\x19RTMR_TABLET_EXECUTOR_READ\x10\x89\x01\x12$\n\x1fRTMR_TABLET_EXECUTOR_READBLOCKS\x10\x8a\x01\x12#\n\x1eRTMR_TABLET_EXECUTOR_READSTATS\x10\x8b\x01\x12\"\n\x1dRTMR_TABLET_EXECUTOR_RECOVERY\x10\x8c\x01\x12&\n!RTMR_TABLET_EXECUTOR_FOLLOWERREAD\x10\x8d\x01\x12(\n#RTMR_TABLET_EXECUTOR_FOLLOWERUPDATE\x10\x8e\x01\x12\"\n\x1dRTMR_TABLET_EXECUTOR_SNAPSHOT\x10\x8f\x01\x12 \n\x1bRTMR_TABLET_EXECUTOR_UPDATE\x10\x90\x01\x12%\n RTMR_TABLET_EXECUTOR_UPDATESTATS\x10\x91\x01\x12#\n\x1eRTMR_TABLET_EXECUTOR_WRITEBLOB\x10\x92\x01\x12\x16\n\x11RTMR_TABLET_PROXY\x10\x93\x01\x12\x18\n\x13RTMR_TABLET_SERVICE\x10\x94\x01\x12\x13\n\x0e\x42S_QUEUE_ACTOR\x10\x95\x01\x12\x1f\n\x1a\x42S_ASYNC_REPLSST_COMMITTER\x10\x96\x01\x12\x1b\n\x16\x46LAT_SCHEMESHARD_ACTOR\x10\x97\x01\x12\x19\n\x14\x42S_HULL_REPL_PLANNER\x10\x98\x01\x12\x12\n\rPROXY_GATEWAY\x10\x99\x01\x12\x1c\n\x17\x42S_PROXY_MULTIGET_ACTOR\x10\x9a\x01\x12\x14\n\x0fPERSQUEUE_ACTOR\x10\x9b\x01\x12\x1e\n\x19PERSQUEUE_PARTITION_ACTOR\x10\x9c\x01\x12\x1a\n\x15PERSQUEUE_CACHE_ACTOR\x10\x9d\x01\x12\x18\n\x13PERSQUEUE_MON_ACTOR\x10\x9e\x01\x12\x18\n\x13PERSQUEUE_ANS_ACTOR\x10\x9f\x01\x12\x10\n\x0bOBJ_DELETER\x10\xa0\x01\x12\x12\n\rBS_LOAD_ACTOR\x10\xa1\x01\x12\x0f\n\nHIVE_ACTOR\x10\xa2\x01\x12\x18\n\x13HIVE_BALANCER_ACTOR\x10\xa3\x01\x12\x1a\n\x15\x42S_DISK_SPACE_TRACKER\x10\xa4\x01\x12\x12\n\rFLAT_EXECUTOR\x10\xa5\x01\x12 \n\x1b\x42S_PROXY_MULTICOLLECT_ACTOR\x10\xa6\x01\x12\x18\n\x13PERSQUEUE_METACACHE\x10\xa7\x01\x12#\n\x1e\x42S_PROXY_INDEXRESTOREGET_ACTOR\x10\xa8\x01\x12$\n\x1f\x42S_HULLQUERY_EXTREME_INDEX_ONLY\x10\xa9\x01\x12\x1e\n\x19\x42S_HULLQUERY_EXTREME_DATA\x10\xaa\x01\x12\x18\n\x13INTERCONNECT_COMMON\x10\xab\x01\x12\x12\n\rMSGBUS_COMMON\x10\xac\x01\x12\x0f\n\nJOB_COMMON\x10\xad\x01\x12\x1c\n\x17LABELS_MAINTAINER_ACTOR\x10\xae\x01\x12\x11\n\x0cHEALTH_ACTOR\x10\xaf\x01\x12\x0f\n\nHEALTH_MON\x10\xb0\x01\x12$\n\x1f\x42S_SYNC_OBTAIN_VDISK_GUID_PROXY\x10\xb1\x01\x12\x1d\n\x18PERSQUEUE_CACHE_L2_ACTOR\x10\xb2\x01\x12\x1a\n\x15\x42S_PROXY_STATUS_ACTOR\x10\xb3\x01\x12\x1d\n\x18TABLET_REQ_DELETE_TABLET\x10\xb4\x01\x12\x1a\n\x15\x42S_SYNCER_LOCALWRITER\x10\xb5\x01\x12\x18\n\x13TOKEN_BUILDER_ACTOR\x10\xb6\x01\x12\x18\n\x13TICKET_PARSER_ACTOR\x10\xb7\x01\x12\x14\n\x0fKQP_PROXY_ACTOR\x10\xb8\x01\x12\x15\n\x10KQP_WORKER_ACTOR\x10\xb9\x01\x12\x14\n\x0f\x41SYNC_DESTROYER\x10\xba\x01\x12\x1d\n\x18\x42LACKBOX_VALIDATOR_ACTOR\x10\xbb\x01\x12 \n\x1b\x42S_SYNC_VDISK_GUID_RECOVERY\x10\xbc\x01\x12!\n\x1c\x42S_SYNC_VDISK_GUID_FIRST_RUN\x10\xbd\x01\x12#\n\x1e\x42S_SYNC_WRITE_VDISK_GUID_PROXY\x10\xbe\x01\x12\x13\n\x0e\x42S_SYNCER_MAIN\x10\xbf\x01\x12\x1e\n\x19\x42S_SYNCER_GUID_PROPAGATOR\x10\xc0\x01\x12 \n\x1b\x42S_SYNCER_RECOVER_LOST_DATA\x10\xc1\x01\x12\x13\n\x0e\x42S_REPL_BROKER\x10\xc2\x01\x12\x18\n\x13\x42S_LOAD_PDISK_WRITE\x10\xc3\x01\x12\x17\n\x12\x42S_LOAD_PDISK_READ\x10\xc4\x01\x12\x1e\n\x19\x42S_SYNCER_COMMITTER_PROXY\x10\xc5\x01\x12!\n\x1c\x42S_DELAYED_HUGE_BLOB_DELETER\x10\xc6\x01\x12\x17\n\x12\x42S_BULK_SST_LOADER\x10\xc7\x01\x12\x18\n\x13\x42S_INCR_HUGE_KEEPER\x10\xc8\x01\x12&\n!BS_INCR_HUGE_KEEPER_RECOVERY_SCAN\x10\xc9\x01\x12*\n%BS_INCR_HUGE_KEEPER_RECOVERY_READ_LOG\x10\xca\x01\x12\x13\n\x0e\x42S_HULL_OSIRIS\x10\xcb\x01\x12\x16\n\x11\x42S_SYNCER_HTTPREQ\x10\xcc\x01\x12\x19\n\x14\x42S_FAILURE_INJECTION\x10\xcd\x01\x12\x11\n\x0c\x42S_GET_ACTOR\x10\xce\x01\x12\x14\n\x0fSELF_PING_ACTOR\x10\xcf\x01\x12\x16\n\x11STORE_TO_YT_ACTOR\x10\xd0\x01\x12\x0f\n\nGRPC_PROXY\x10\xd1\x01\x12\x14\n\x0fNODE_IDENTIFIER\x10\xd2\x01\x12\x15\n\x10\x42S_SYNCER_ANUBIS\x10\xd3\x01\x12\"\n\x1dPERSQUEUE_READ_BALANCER_ACTOR\x10\xd4\x01\x12\x12\n\rSAUSAGE_CACHE\x10\xd5\x01\x12\x16\n\x11\x46RONT_BSADM_PDISK\x10\xd6\x01\x12\x17\n\x12\x46RONT_BSADM_VSLOTS\x10\xd7\x01\x12\x16\n\x11\x46RONT_BSADM_GROUP\x10\xd8\x01\x12\x1f\n\x1a\x46RONT_BSADM_RECONF_REPLACE\x10\xd9\x01\x12\x1c\n\x17\x46RONT_BSADM_RECONF_WIPE\x10\xda\x01\x12\x17\n\x12\x46RONT_BSADM_CONFIG\x10\xdb\x01\x12\x15\n\x10\x46RONT_DS_SETCONF\x10\xdc\x01\x12\x15\n\x10\x46RONT_KV_REQUEST\x10\xdd\x01\x12\x15\n\x10\x46RONT_LOCAL_MQKL\x10\xde\x01\x12\x15\n\x10\x46RONT_LOCAL_TXRQ\x10\xdf\x01\x12\x16\n\x11\x46RONT_GETCOUNTERS\x10\xe0\x01\x12\x18\n\x13\x46RONT_POISON_TABLET\x10\xe1\x01\x12\x1a\n\x15\x46RONT_SCHEME_TXSTATUS\x10\xe2\x01\x12\x1c\n\x17\x46RONT_ENUMERATE_TABLETS\x10\xe3\x01\x12\x17\n\x12\x46RONT_MKQL_REQUEST\x10\xe4\x01\x12\x1a\n\x15\x46RONT_SCHEME_DESCRIBE\x10\xe5\x01\x12\x19\n\x14\x46RONT_SCHEME_REQUEST\x10\xe6\x01\x12\x16\n\x11\x46RONT_YQL_REQUEST\x10\xe7\x01\x12\x13\n\x0e\x46RONT_PQ_WRITE\x10\xe8\x01\x12\x14\n\x0f\x46RONT_PQ_COMMIT\x10\xe9\x01\x12\x12\n\rFRONT_PQ_READ\x10\xea\x01\x12\x17\n\x12\x46RONT_PQ_PARTITION\x10\xeb\x01\x12\x1c\n\x17\x46RONT_GRPC_PROXY_STATUS\x10\xec\x01\x12\x17\n\x12\x46RONT_CHOOSE_RROXY\x10\xed\x01\x12\x0b\n\x06WHOAMI\x10\xee\x01\x12\x1c\n\x17\x42LOCKSTORE_BOOTSTRAPPER\x10\xef\x01\x12\x1a\n\x15\x42LOCKSTORE_HIVE_PROXY\x10\xf0\x01\x12\x19\n\x14\x42LOCKSTORE_PARTITION\x10\xf1\x01\x12\x19\n\x14\x42LOCKSTORE_SCHEDULER\x10\xf2\x01\x12\x17\n\x12\x42LOCKSTORE_SERVICE\x10\xf3\x01\x12\x1d\n\x18\x42LOCKSTORE_SERVICE_PROXY\x10\xf4\x01\x12\x18\n\x13\x42LOCKSTORE_SS_PROXY\x10\xf5\x01\x12\x16\n\x11\x42LOCKSTORE_VOLUME\x10\xf6\x01\x12\x12\n\rSAUSAGE_BIO_A\x10\xf7\x01\x12\x17\n\x12KQP_EXECUTER_ACTOR\x10\xf8\x01\x12\x18\n\x13USER_REGISTRY_ACTOR\x10\xf9\x01\x12\x1f\n\x1aTVM_SETTINGS_UPDATER_ACTOR\x10\xfa\x01\x12\x1e\n\x19PQ_BASE_REQUEST_PROCESSOR\x10\xfb\x01\x12\x1e\n\x19PQ_META_REQUEST_PROCESSOR\x10\xfc\x01\x12\x0f\n\nFAKE_ENV_A\x10\xfd\x01\x12\x13\n\x0eVIEWER_HANDLER\x10\xfe\x01\x12\x1c\n\x17\x44\x41TASHARD_STATS_BUILDER\x10\xff\x01\x12\x16\n\x11KESUS_PROXY_ACTOR\x10\x80\x02\x12\x17\n\x12KESUS_TABLET_ACTOR\x10\x81\x02\x12\x18\n\x13RTMR_IC_BUS_SERVICE\x10\x82\x02\x12 \n\x1b\x42LOCKSTORE_PARTITION_WORKER\x10\x83\x02\x12\x18\n\x13TX_DATASHARD_COMMON\x10\x84\x02\x12#\n\x1eRTMR_TABLET_EXECUTOR_READBLOBS\x10\x85\x02\x12\x1c\n\x17\x44S_PROXY_NODE_MON_ACTOR\x10\x86\x02\x12\x16\n\x11KQP_COMPUTE_ACTOR\x10\x87\x02\x12\x16\n\x11SQS_SERVICE_ACTOR\x10\x88\x02\x12\x0e\n\tSQS_ACTOR\x10\x89\x02\x12\x14\n\x0fSQS_PROXY_ACTOR\x10\x8a\x02\x12\x18\n\x13\x43MS_TENANTS_MANAGER\x10\x8b\x02\x12\x18\n\x13\x43MS_CONFIGS_MANAGER\x10\x8c\x02\x12\x19\n\x14\x43MS_CONFIGS_PROVIDER\x10\x8d\x02\x12\x1b\n\x16\x43MS_CONFIGS_SUBSCRIBER\x10\x8e\x02\x12\x1d\n\x18\x43ONFIGS_DISPATCHER_ACTOR\x10\x8f\x02\x12\x18\n\x13\x42OARD_REPLICA_ACTOR\x10\x90\x02\x12\x17\n\x12\x42OARD_LOOKUP_ACTOR\x10\x91\x02\x12\x18\n\x13\x42OARD_PUBLISH_ACTOR\x10\x92\x02\x12 \n\x1b\x42OARD_REPLICA_PUBLISH_ACTOR\x10\x93\x02\x12\x17\n\x12USER_FETCHER_ACTOR\x10\x94\x02\x12!\n\x1cTABLET_RESPONSIVENESS_PINGER\x10\x95\x02\x12\x16\n\x11\x42S_GROUP_OBSERVER\x10\x96\x02\x12\x11\n\x0cGRPC_UPDATER\x10\x97\x02\x12\x1a\n\x15TABLE_SCHEME_RESOLVER\x10\x98\x02\x12\x15\n\x10\x42S_GROUP_REQUEST\x10\x99\x02\x12\x12\n\rTABLET_KILLER\x10\x9a\x02\x12\x17\n\x12TEST_ACTOR_RUNTIME\x10\x9b\x02\x12\x1b\n\x16INTERCONNECT_HANDSHAKE\x10\x9c\x02\x12\x18\n\x13INTERCONNECT_POLLER\x10\x9d\x02\x12 \n\x1bINTERCONNECT_SESSION_KILLER\x10\x9e\x02\x12\x1c\n\x17IMMEDIATE_CONTROL_BOARD\x10\x9f\x02\x12\x1c\n\x17\x44S_PROXY_OVERSEER_ACTOR\x10\xa0\x02\x12\x18\n\x13KQP_REQUEST_HANDLER\x10\xa1\x02\x12\x18\n\x13KESUS_RESOLVE_ACTOR\x10\xa2\x02\x12\x15\n\x10HIVE_MON_REQUEST\x10\xa3\x02\x12\x16\n\x11IAM_SERVICE_ACTOR\x10\xa4\x02\x12\x1d\n\x18IAM_SERVICE_AUTHENTICATE\x10\xa5\x02\x12\x1a\n\x15IAM_SERVICE_AUTHORIZE\x10\xa6\x02\x12\x13\n\x0e\x44\x45\x46\x45RRABLE_RPC\x10\xa7\x02\x12\x12\n\rCMS_MON_PDISK\x10\xa8\x02\x12\x12\n\rGRPC_REQ_AUTH\x10\xa9\x02\x12\x1a\n\x15GRPC_ENDPOINT_PUBLISH\x10\xaa\x02\x12\x1d\n\x18NODE_BROKER_LEASE_HOLDER\x10\xab\x02\x12\x17\n\x12\x43MS_INFO_COLLECTOR\x10\xac\x02\x12\x12\n\rCMS_WALLE_REQ\x10\xad\x02\x12\x0e\n\tKESUS_REQ\x10\xae\x02\x12\r\n\x08GRPC_REQ\x10\xaf\x02\x12\x18\n\x13\x42LOCKSTORE_METERING\x10\xb0\x02\x12!\n\x1cSQS_CLEANUP_BACKGROUND_ACTOR\x10\xb1\x02\x12#\n\x1eSQS_RETENTION_BACKGROUND_ACTOR\x10\xb2\x02\x12\x14\n\x0fSQS_PURGE_ACTOR\x10\xb3\x02\x12\x17\n\x12SQS_EXECUTOR_ACTOR\x10\xb4\x02\x12#\n\x1eKQP_TABLE_PROFILE_LOADER_ACTOR\x10\xb5\x02\x12\x19\n\x14\x46OLDER_SERVICE_ACTOR\x10\xb6\x02\x12\x1f\n\x1a\x46OLDER_SERVICE_LIST_FOLDER\x10\xb7\x02\x12!\n\x1c\x41\x43TOR_SYSTEM_SCHEDULER_ACTOR\x10\xb8\x02\x12\x1c\n\x17SQS_PROXY_SERVICE_ACTOR\x10\xb9\x02\x12\x1b\n\x16SQS_QUEUE_LEADER_ACTOR\x10\xba\x02\x12\x18\n\x13TABLET_LOOKUP_ACTOR\x10\xbb\x02\x12\x17\n\x12TRACE_LOOKUP_ACTOR\x10\xbc\x02\x12\x18\n\x13TRACE_REQUEST_ACTOR\x10\xbd\x02\x12\x1e\n\x19SIGNAL_BODY_REQUEST_ACTOR\x10\xbe\x02\x12\x10\n\x0bTABLET_INFO\x10\xbf\x02\x12\x14\n\x0fGRPC_STREAM_REQ\x10\xc0\x02\x12\x17\n\x12TX_READ_TABLE_SCAN\x10\xc1\x02\x12\x1b\n\x16\x42LOCKSTORE_SCHEMESHARD\x10\xc2\x02\x12\r\n\x08GRPC_MON\x10\xc3\x02\x12\x1e\n\x19LOG_SETTINGS_CONFIGURATOR\x10\xc4\x02\x12\x19\n\x14QUOTER_SERVICE_ACTOR\x10\xc5\x02\x12\x17\n\x12QUOTER_PROXY_ACTOR\x10\xc6\x02\x12\x19\n\x14\x41\x43\x43\x45SS_SERVICE_ACTOR\x10\xc7\x02\x12 \n\x1b\x41\x43\x43\x45SS_SERVICE_AUTHENTICATE\x10\xc8\x02\x12\x1d\n\x18\x41\x43\x43\x45SS_SERVICE_AUTHORIZE\x10\xc9\x02\x12\x1f\n\x1aUSER_ACCOUNT_SERVICE_ACTOR\x10\xca\x02\x12\x1d\n\x18USER_ACCOUNT_SERVICE_GET\x10\xcb\x02\x12*\n%RTMR_TABLET_EXECUTOR_SETMETADATAATTRS\x10\xcc\x02\x12\x1c\n\x17\x42LOCKSTORE_VOLUME_PROXY\x10\xcd\x02\x12\x1e\n\x19SQS_QUEUE_MIGRATION_ACTOR\x10\xce\x02\x12\x13\n\x0eSQS_PING_ACTOR\x10\xcf\x02\x12\x1f\n\x1aSCHEME_BOARD_REPLICA_ACTOR\x10\xd0\x02\x12\x1a\n\x15\x41\x43TOR_FUTURE_CALLBACK\x10\xd1\x02\x12\"\n\x1dSCHEME_BOARD_SUBSCRIBER_ACTOR\x10\xd2\x02\x12*\n%SCHEME_BOARD_REPLICA_SUBSCRIBER_ACTOR\x10\xd3\x02\x12!\n\x1cSCHEME_BOARD_POPULATOR_ACTOR\x10\xd4\x02\x12)\n$SCHEME_BOARD_REPLICA_POPULATOR_ACTOR\x10\xd5\x02\x12\x1e\n\x19SHARED_CACHE_CONFIGURATOR\x10\xd6\x02\x12\x17\n\x12SQS_METERING_ACTOR\x10\xd7\x02\x12#\n\x1eIMMEDITE_CONTROLS_CONFIGURATOR\x10\xd8\x02\x12#\n\x1eSQS_USER_SETTINGS_READER_ACTOR\x10\xd9\x02\x12&\n!KQP_EXEC_PHYSICAL_REQUEST_HANDLER\x10\xda\x02\x12\x1d\n\x18TENANT_SLOT_BROKER_ACTOR\x10\xdb\x02\x12\x19\n\x14GROUP_BALANCER_ACTOR\x10\xdc\x02\x12\x18\n\x13\x42S_CONTROLLER_ACTOR\x10\xdd\x02\x12\x16\n\x11TENANT_POOL_ACTOR\x10\xde\x02\x12\x10\n\x0bLOCAL_ACTOR\x10\xdf\x02\x12\x10\n\x0bNODE_WARDEN\x10\xe0\x02\x12\x18\n\x13TABLET_BOOTSTRAPPER\x10\xe1\x02\x12\x17\n\x12\x42SC_STAT_PROCESSOR\x10\xe2\x02\x12!\n\x1cSQS_QUEUES_LIST_READER_ACTOR\x10\xe3\x02\x12\x14\n\x0fTX_PROXY_EXPORT\x10\xe4\x02\x12\x1b\n\x16KQP_SCAN_COMPUTE_ACTOR\x10\xe5\x02\x12\x13\n\x0eKQP_TABLE_SCAN\x10\xe6\x02\x12\x1c\n\x17\x43ONFIGURED_BOOTSTRAPPER\x10\xe7\x02\x12\x1e\n\x19TX_ALLOCATOR_CLIENT_ACTOR\x10\xe8\x02\x12\x14\n\x0f\x42LOCKSTORE_AUTH\x10\xe9\x02\x12\x1a\n\x15INTERCONNECT_MONACTOR\x10\xea\x02\x12\x17\n\x12\x42S_MONSTREAM_ACTOR\x10\xeb\x02\x12\x1f\n\x1aNODE_WARDEN_STATAGGR_ACTOR\x10\xec\x02\x12\x19\n\x14UPLOAD_ROWS_INTERNAL\x10\xed\x02\x12\x1e\n\x19PERSQUEUE_CLUSTER_TRACKER\x10\xee\x02\x12\x19\n\x14NET_CLASSIFIER_ACTOR\x10\xef\x02\x12\x18\n\x13KQP_COMPILE_SERVICE\x10\xf0\x02\x12\x16\n\x11KQP_COMPILE_ACTOR\x10\xf1\x02\x12 \n\x1bPERSQUEUE_CLUSTER_DISCOVERY\x10\xf2\x02\x12\x17\n\x12TX_FILL_INDEX_SCAN\x10\xf3\x02\x12\x1b\n\x16NET_CLASSIFIER_UPDATER\x10\xf4\x02\x12\x1c\n\x17\x42S_LOAD_PDISK_LOG_WRITE\x10\xf5\x02\x12\x1f\n\x1aRTMR_CONFIGURATION_STORAGE\x10\xf6\x02\x12\x19\n\x14KQP_SYSTEM_VIEW_SCAN\x10\xf7\x02\x12\x1c\n\x17INTERCONNECT_LOAD_ACTOR\x10\xf8\x02\x12 \n\x1bINTERCONNECT_LOAD_RESPONDER\x10\xf9\x02\x12 \n\x1bINTERCONNECT_DESTRUCT_ACTOR\x10\xfa\x02\x12\x17\n\x12\x42S_MIGRATION_ACTOR\x10\xfb\x02\x12 \n\x1bSQS_GARBAGE_COLLECTOR_ACTOR\x10\xfc\x02\x12\x18\n\x13SYSTEM_VIEW_SERVICE\x10\xfd\x02\x12\x17\n\x12\x43MS_SENTINEL_ACTOR\x10\xfe\x02\x12&\n!CMS_SENTINEL_CONFIG_UPDATER_ACTOR\x10\xff\x02\x12%\n CMS_SENTINEL_STATE_UPDATER_ACTOR\x10\x80\x03\x12&\n!CMS_SENTINEL_STATUS_CHANGER_ACTOR\x10\x81\x03\x12\x1d\n\x18TENANT_NODES_ENUMERATION\x10\x82\x03\x12$\n\x1fSCHEME_BOARD_SYNCHRONIZER_ACTOR\x10\x83\x03\x12,\n\'SCHEME_BOARD_REPLICA_SYNCHRONIZER_ACTOR\x10\x84\x03\x12%\n SYSTEM_VIEW_PART_STATS_COLLECTOR\x10\x85\x03\x12\x1a\n\x15\x42LOCKSTORE_DISK_AGENT\x10\x86\x03\x12\x1d\n\x18\x42LOCKSTORE_DISK_REGISTRY\x10\x87\x03\x12\x16\n\x11\x45XPORT_SCAN_ACTOR\x10\x88\x03\x12\x1d\n\x18\x45XPORT_YT_UPLOADER_ACTOR\x10\x89\x03\x12\x1d\n\x18\x45XPORT_S3_UPLOADER_ACTOR\x10\x8a\x03\x12\x1a\n\x15YF_SYNC_SERVICE_ACTOR\x10\x8b\x03\x12!\n\x1cYF_SYNC_SERVICE_WORKER_ACTOR\x10\x8c\x03\x12\"\n\x1dYF_DESCRIPTIONS_SERVICE_ACTOR\x10\x8d\x03\x12\x1b\n\x16YF_GW_SERIALIZER_ACTOR\x10\x8e\x03\x12\x15\n\x10YF_SERVICE_ACTOR\x10\x8f\x03\x12\"\n\x1dYF_WORKER_ACTOR_SERVICE_ACTOR\x10\x90\x03\x12\'\n\"YF_RTMR_WORKER_ACTOR_SERVICE_ACTOR\x10\x91\x03\x12 \n\x1bYF_NAMESERVER_WRAPPER_ACTOR\x10\x92\x03\x12$\n\x1fYF_DIRECT_CLIENT_BALANCER_ACTOR\x10\x93\x03\x12\x13\n\x0eYF_AGENT_ACTOR\x10\x94\x03\x12\x1b\n\x16YF_ARCHIVE_CACHE_ACTOR\x10\x95\x03\x12\x1c\n\x17YF_ARTIFACT_CACHE_ACTOR\x10\x96\x03\x12\x1d\n\x18YF_SKY_GET_COMMAND_ACTOR\x10\x97\x03\x12\x16\n\x11YF_UNPACKER_ACTOR\x10\x98\x03\x12\x1b\n\x16YF_CALL_BALANCER_ACTOR\x10\x99\x03\x12\x15\n\x10YF_GATEWAY_ACTOR\x10\x9a\x03\x12\x1d\n\x18YF_GATEWAY_SERVICE_ACTOR\x10\x9b\x03\x12*\n%YF_GRPC_SERVICE_COUNTER_UPDATER_ACTOR\x10\x9c\x03\x12\x1e\n\x19YF_INFLIGHT_REQUEST_ACTOR\x10\x9d\x03\x12\x19\n\x14YF_MON_SERVICE_ACTOR\x10\x9e\x03\x12\x19\n\x14YF_SKY_FETCHER_ACTOR\x10\x9f\x03\x12&\n!YF_LIST_INSTANCES_JOB_CACHE_ACTOR\x10\xa0\x03\x12\x17\n\x12YF_IC_CLIENT_ACTOR\x10\xa1\x03\x12\"\n\x1dYF_DIRECT_CLIENT_SENDER_ACTOR\x10\xa2\x03\x12\x1b\n\x16YF_QUEUED_FECTER_ACTOR\x10\xa3\x03\x12\x1e\n\x19YF_GRPC_JOB_SERVICE_ACTOR\x10\xa4\x03\x12\x1a\n\x15YF_HTTP_FETCHER_ACTOR\x10\xa5\x03\x12 \n\x1bYF_JOB_SERVICE_LEADER_ACTOR\x10\xa6\x03\x12\x1f\n\x1aYF_JOB_SERVICE_PROXY_ACTOR\x10\xa7\x03\x12)\n$YF_JOB_SERVICE_SESSION_MONITOR_ACTOR\x10\xa8\x03\x12 \n\x1bYF_JOB_SERVICE_WORKER_ACTOR\x10\xa9\x03\x12\x1e\n\x19YF_LOCAL_FS_FETCHER_ACTOR\x10\xaa\x03\x12#\n\x1eYF_RUNNER_WORKER_PRIVATE_ACTOR\x10\xab\x03\x12\x1c\n\x17YF_RUNNER_PRIVATE_ACTOR\x10\xac\x03\x12\'\n\"YF_REQUEST_REGISTER_FUNCTION_ACTOR\x10\xad\x03\x12\"\n\x1dSERVICE_ACCOUNT_SERVICE_ACTOR\x10\xae\x03\x12#\n\x1e\x42LOCKSTORE_DISK_REGISTRY_PROXY\x10\xaf\x03\x12\x1f\n\x1a\x42SC_SYSTEM_VIEWS_COLLECTOR\x10\xb0\x03\x12\x19\n\x14KQP_RESOURCE_MANAGER\x10\xb1\x03\x12)\n$YF_REQUEST_UNREGISTER_FUNCTION_ACTOR\x10\xb2\x03\x12\'\n\"YF_REQUEST_DESCRIBE_FUNCTION_ACTOR\x10\xb3\x03\x12$\n\x1fYF_REQUEST_LIST_FUNCTIONS_ACTOR\x10\xb4\x03\x12$\n\x1fYF_REQUEST_LIST_ENDPOINTS_ACTOR\x10\xb5\x03\x12$\n\x1fYF_REQUEST_LIST_INSTANCES_ACTOR\x10\xb6\x03\x12)\n$YF_REQUEST_GENERATE_UPLOAD_URL_ACTOR\x10\xb7\x03\x12#\n\x1eYF_REQUEST_CALL_FUNCTION_ACTOR\x10\xb8\x03\x12\x1d\n\x18SCHEME_BOARD_DB_RESOLVER\x10\xb9\x03\x12\x14\n\x0fYF_LOGGER_ACTOR\x10\xba\x03\x12&\n!CONDITIONAL_ERASE_ROWS_SCAN_ACTOR\x10\xbb\x03\x12\x1f\n\x1a\x42LOCKSTORE_VOLUME_BALANCER\x10\xbc\x03\x12$\n\x1f\x42LOCKSTORE_DISK_REGISTRY_WORKER\x10\xbd\x03\x12!\n\x1c\x42LOCKSTORE_DISK_AGENT_WORKER\x10\xbe\x03\x12\x1a\n\x15SYSTEM_VIEW_PROCESSOR\x10\xbf\x03\x12\"\n\x1dVDISK_LOCALSYNCDATA_EXTRACTOR\x10\xc0\x03\x12$\n\x1fVDISK_FRESH_APPENDIX_COMPACTION\x10\xc1\x03\x12\x10\n\x0bNAMESERVICE\x10\xc2\x03\x12\x17\n\x12PERSQUEUE_MIRRORER\x10\xc3\x03\x12\x14\n\x0fLONG_TX_SERVICE\x10\xc4\x03\x12\x1b\n\x16LONG_TX_SERVICE_COMMIT\x10\xc5\x03\x12!\n\x1cPERSQUEUE_READ_SPEED_LIMITER\x10\xc6\x03\x12%\n LONG_TX_SERVICE_ACQUIRE_SNAPSHOT\x10\xc7\x03\x12!\n\x1c\x42LOCKSTORE_PARTITION_NONREPL\x10\xc8\x03\x12\x19\n\x14\x42S_PROXY_PATCH_ACTOR\x10\xc9\x03\x12#\n\x1eSCHEME_BOARD_WATCH_CACHE_ACTOR\x10\xca\x03\x12\x18\n\x13SEQUENCESHARD_ACTOR\x10\xcb\x03\x12\x1b\n\x16\x42UILD_INDEX_SCAN_ACTOR\x10\xcc\x03\x12\x1b\n\x16\x46LAT_EXECUTOR_REASSIGN\x10\xcd\x03\x12!\n\x1c\x44ISTRIBUTED_ERASE_ROWS_ACTOR\x10\xce\x03\x12\x15\n\x10YT_WRAPPER_ACTOR\x10\xcf\x03\x12\x1a\n\x15YT_TABLE_WRITER_ACTOR\x10\xd0\x03\x12(\n#SCHEME_BOARD_SUBSCRIBER_PROXY_ACTOR\x10\xd1\x03\x12\x15\n\x10S3_WRAPPER_ACTOR\x10\xd2\x03\x12\x1a\n\x15\x46ILESTORE_SCHEMESHARD\x10\xd3\x03\x12\x16\n\x11\x46ILESTORE_SERVICE\x10\xd4\x03\x12\x1d\n\x18\x46ILESTORE_SERVICE_WORKER\x10\xd5\x03\x12\x17\n\x12TX_OLAPSHARD_ACTOR\x10\xd6\x03\x12\x15\n\x10\x46ILESTORE_TABLET\x10\xd7\x03\x12\x1c\n\x17\x46ILESTORE_TABLET_WORKER\x10\xd8\x03\x12\x1b\n\x16\x46ILESTORE_TABLET_PROXY\x10\xd9\x03\x12\x17\n\x12\x46ILESTORE_SS_PROXY\x10\xda\x03\x12\x1f\n\x1aIMPORT_S3_DOWNLOADER_ACTOR\x10\xdb\x03\x12\x13\n\x0eMEMORY_TRACKER\x10\xdc\x03\x12\x19\n\x14TX_COLUMNSHARD_ACTOR\x10\xdd\x03\x12\x1f\n\x1aTX_COLUMNSHARD_WRITE_ACTOR\x10\xf0\x03\x12\x1e\n\x19TX_COLUMNSHARD_READ_ACTOR\x10\xf1\x03\x12\"\n\x1dTX_COLUMNSHARD_INDEXING_ACTOR\x10\xf2\x03\x12$\n\x1fTX_COLUMNSHARD_COMPACTION_ACTOR\x10\xf3\x03\x12\"\n\x1dTX_COLUMNSHARD_EVICTION_ACTOR\x10\xf9\x03\x12\"\n\x1dSCHEME_BOARD_MONITORING_ACTOR\x10\xde\x03\x12&\n!SCHEME_BOARD_INFO_REQUESTER_ACTOR\x10\xdf\x03\x12\x1a\n\x15METERING_WRITER_ACTOR\x10\xe0\x03\x12\x1b\n\x16SEQUENCE_PROXY_SERVICE\x10\xe1\x03\x12\x19\n\x14KQP_TABLE_SCAN_PROXY\x10\xe2\x03\x12\x17\n\x12KQP_TABLE_RESOLVER\x10\xe3\x03\x12\x1d\n\x18KQP_RESULT_CHANNEL_PROXY\x10\xe4\x03\x12\x18\n\x13KQP_SHARDS_RESOLVER\x10\xe5\x03\x12\x18\n\x13KQP_COMPILE_REQUEST\x10\xe6\x03\x12\x0e\n\tBS_DEFRAG\x10\xe7\x03\x12\x16\n\x11\x42S_DEFRAG_QUANTUM\x10\xe8\x03\x12\x1f\n\x1aKQP_LITERAL_EXECUTER_ACTOR\x10\xe9\x03\x12\x1c\n\x17\x46ILESTORE_SERVICE_PROXY\x10\xea\x03\x12\'\n\"TX_DATASHARD_SOURCE_OFFSETS_SERVER\x10\xeb\x03\x12\x12\n\rKQP_OLAP_SCAN\x10\xec\x03\x12\x1c\n\x17KQP_DATA_EXECUTER_ACTOR\x10\xed\x03\x12\x15\n\x10KQP_NODE_SERVICE\x10\xee\x03\x12\'\n\"TX_DATASHARD_SOURCE_OFFSETS_CLIENT\x10\xf4\x03\x12/\n*COORDINATOR_READ_STEP_SUBSCRIPTION_MANAGER\x10\xf5\x03\x12\x1f\n\x1aTX_MEDIATOR_TIMECAST_ACTOR\x10\xf6\x03\x12$\n\x1fTX_MEDIATOR_EXECUTE_QUEUE_ACTOR\x10\xf7\x03\x12#\n\x1eTX_MEDIATOR_TABLET_QUEUE_ACTOR\x10\xf8\x03\x12\x14\n\x0fYQL_PROXY_ACTOR\x10\xfe\x03\x12\x15\n\x10TEST_SHARD_ACTOR\x10\xff\x03\x12\x1d\n\x18\x46RONT_TEST_SHARD_REQUEST\x10\x80\x04\x12!\n\x1cSTATE_SERVER_INTERFACE_ACTOR\x10\x81\x04\x12\x1c\n\x17IAM_TOKEN_SERVICE_ACTOR\x10\x82\x04\x12\x1b\n\x16YQL_EXECUTE_PLAN_ACTOR\x10\x83\x04\x12\x16\n\x11YQL_DB_POOL_ACTOR\x10\x84\x04\x12\x12\n\rYQL_RUN_ACTOR\x10\x85\x04\x12\"\n\x1dYQL_GET_HISTORY_REQUEST_ACTOR\x10\x86\x04\x12\x1e\n\x19YQL_GET_RESULT_DATA_ACTOR\x10\x87\x04\x12\x15\n\x10\x42LOB_CACHE_ACTOR\x10\x88\x04\x12\x17\n\x12MONITORING_SERVICE\x10\x89\x04\x12\x17\n\x12MONITORING_REQUEST\x10\x8a\x04\x12\x18\n\x13\x41\x43TOR_SERVICE_CACHE\x10\x8b\x04\x12\x18\n\x13\x43HANGE_SENDER_ACTOR\x10\x8c\x04\x12)\n$CHANGE_SENDER_ASYNC_INDEX_ACTOR_MAIN\x10\x8d\x04\x12.\n)CHANGE_SENDER_ASYNC_INDEX_ACTOR_PARTITION\x10\x8e\x04\x12&\n!YQL_GET_CONNECTIONS_REQUEST_ACTOR\x10\x8f\x04\x12)\n$YQL_MODIFY_CONNECTIONS_REQUEST_ACTOR\x10\x90\x04\x12%\n YQL_MODIFY_HISTORY_REQUEST_ACTOR\x10\x91\x04\x12 \n\x1bYQL_WRITE_RESULT_DATA_ACTOR\x10\x92\x04\x12\x13\n\x0e\x42S_SCRUB_ACTOR\x10\x93\x04\x12\x1b\n\x16\x42S_BLOB_RECOVERY_ACTOR\x10\x94\x04\x12$\n\x1f\x42S_RESTORE_CORRUPTED_BLOB_ACTOR\x10\x95\x04\x12#\n\x1eYQ_CONTROL_PLANE_STORAGE_ACTOR\x10\x96\x04\x12!\n\x1cYQ_CONTROL_PLANE_PROXY_ACTOR\x10\x97\x04\x12\x15\n\x10\x44\x42_WATCHER_ACTOR\x10\xef\x03\x12\x1e\n\x19YQL_PENDING_FETCHER_ACTOR\x10\x98\x04\x12\x15\n\x10YQL_PINGER_ACTOR\x10\x99\x04\x12\x1c\n\x17YQL_PRIVATE_PROXY_ACTOR\x10\x9a\x04\x12 \n\x1bYQL_PRIVATE_PING_TASK_ACTOR\x10\x9b\x04\x12\x1f\n\x1a\x45XT_COUNTERS_UPDATER_ACTOR\x10\x9c\x04\x12\x1f\n\x1aYQL_PRIVATE_GET_TASK_ACTOR\x10\x9d\x04\x12!\n\x1cYQL_PRIVATE_WRITE_TASK_ACTOR\x10\x9e\x04\x12\x1c\n\x17YQL_NODES_MANAGER_ACTOR\x10\x9f\x04\x12\x1b\n\x16KESUS_ACCOUNTING_ACTOR\x10\xa0\x04\x12 \n\x1b\x42LOCKSTORE_PARTITION_COMMON\x10\xa1\x04\x12\x1f\n\x1aINTERCONNECT_PROXY_WRAPPER\x10\xa2\x04\x12\x1d\n\x18\x43LOUD_STORAGE_HIVE_PROXY\x10\xa3\x04\x12)\n$YQL_PRIVATE_NODES_HEALTH_CHECK_ACTOR\x10\xa4\x04\x12!\n\x1c\x43HANGE_SENDER_CDC_ACTOR_MAIN\x10\xa5\x04\x12\x16\n\x11KQP_TEST_WORKLOAD\x10\xa6\x04\x12\x1e\n\x19PQ_PARTITION_WRITER_ACTOR\x10\xa7\x04\x12&\n!CHANGE_SENDER_CDC_ACTOR_PARTITION\x10\xa8\x04\x12\x16\n\x11KQP_SESSION_ACTOR\x10\xa9\x04\x12 \n\x1b\x43HANGE_EXCHANGE_SPLIT_ACTOR\x10\xaa\x04\x12\x17\n\x12\x42S_DEFRAG_REWRITER\x10\xab\x04\x12\x18\n\x13\x42S_DEFRAG_SCHEDULER\x10\xac\x04\x12\x16\n\x11\x42S_DEFRAG_PLANNER\x10\xad\x04\x12!\n\x1cREPLICATION_CONTROLLER_ACTOR\x10\xae\x04\x12&\n!REPLICATION_CONTROLLER_DISCOVERER\x10\xaf\x04\x12*\n%REPLICATION_CONTROLLER_STREAM_CREATOR\x10\xb1\x04\x12\x1d\n\x18YQ_TEST_CONNECTION_ACTOR\x10\xb0\x04\x12\'\n\"REPLICATION_CONTROLLER_DST_CREATOR\x10\xb2\x04\x12\x1d\n\x18\x42LOCKSTORE_STATS_SERVICE\x10\xb3\x04\x12\x13\n\x0eYQ_AUDIT_ACTOR\x10\xb4\x04\x12 \n\x1bYQ_AUDIT_EVENT_SENDER_ACTOR\x10\xb5\x04\x12\x1a\n\x15\x42LOCKSTORE_USER_STATS\x10\xb6\x04\x12\x1c\n\x17TX_COLUMNSHARD_S3_ACTOR\x10\xb7\x04\x12 \n\x1bTX_COLUMNSHARD_EXPORT_ACTOR\x10\xb8\x04\x12\x14\n\x0fYQ_HEALTH_ACTOR\x10\xb9\x04\x12\x15\n\x10\x42LOB_DEPOT_ACTOR\x10\xba\x04\x12\x1b\n\x16\x42LOB_DEPOT_AGENT_ACTOR\x10\xbb\x04\x12\x1c\n\x17KQP_STREAM_LOOKUP_ACTOR\x10\xbc\x04\x12\x1b\n\x16\x42S_STORAGE_STATS_ACTOR\x10\xbd\x04\x12\x12\n\rDS_LOAD_ACTOR\x10\xbe\x04\x12\x12\n\rPQ_META_CACHE\x10\xbf\x04\x12\x18\n\x13\x42S_GROUP_ASSIMILATE\x10\xc0\x04\x12\x14\n\x0f\x41\x43TOR_COROUTINE\x10\xc1\x04\x12\x14\n\x0fLB_CM_ABC_ACTOR\x10\xc2\x04\x12\x17\n\x12LB_CM_FOLDER_ACTOR\x10\xc3\x04\x12!\n\x1c\x42LOB_DEPOT_ASSIMILATOR_ACTOR\x10\xc4\x04\x12&\n!BLOB_DEPOT_BLOCKS_PROCESSOR_ACTOR\x10\xc5\x04\x12\x1a\n\x15TEST_SHARD_LOAD_ACTOR\x10\xc6\x04\x12 \n\x1bTEST_SHARD_VALIDATION_ACTOR\x10\xc7\x04\x12\x1c\n\x17TX_TIERING_TIER_CLEANER\x10\xc8\x04\x12\x1c\n\x17TX_TIERING_PATH_CLEANER\x10\xc9\x04\x12\x19\n\x14METADATA_INITIALIZER\x10\xca\x04\x12\x19\n\x14TIERING_OWNER_ENRICH\x10\xcb\x04\x12\x1c\n\x17TIERING_SNAPSHOT_ENRICH\x10\xcc\x04\x12\"\n\x1dHTTP_MON_LEGACY_ACTOR_REQUEST\x10\xcd\x04\x12\"\n\x1dHTTP_MON_LEGACY_INDEX_REQUEST\x10\xce\x04\x12\"\n\x1dHTTP_MON_LEGACY_ACTOR_SERVICE\x10\xcf\x04\x12\"\n\x1dHTTP_MON_LEGACY_INDEX_SERVICE\x10\xd0\x04\x12\"\n\x1dHTTP_MON_SERVICE_NODE_REQUEST\x10\xd1\x04\x12!\n\x1cHTTP_MON_SERVICE_MON_REQUEST\x10\xd2\x04\x12 \n\x1bHTTP_MON_SERVICE_NODE_PROXY\x10\xd3\x04\x12\x17\n\x12\x41UDIT_WRITER_ACTOR\x10\xd4\x04\x12\x1d\n\x18SCHEMESHARD_SVP_MIGRATOR\x10\xd5\x04\x12\x16\n\x11SS_FETCHING_ACTOR\x10\xd6\x04\x12&\n!METADATA_SCHEME_DESCRIPTION_ACTOR\x10\xd7\x04*\xbb(\n\x0e\x45ServiceKikimr\x12\x10\n\x0b\x42LOBSTORAGE\x10\x81\x02\x12\x11\n\x0cSTATESTORAGE\x10\x82\x02\x12\x14\n\x0fRESOURCE_BROKER\x10\x83\x02\x12\x10\n\x0b\x42S_SKELETON\x10\x84\x02\x12\x13\n\x0e\x42S_VDISK_BLOCK\x10\x85\x02\x12\x10\n\x0b\x42S_VDISK_GC\x10\x86\x02\x12\x11\n\x0c\x42S_VDISK_GET\x10\x87\x02\x12\x11\n\x0c\x42S_VDISK_PUT\x10\x88\x02\x12\x13\n\x0e\x42S_VDISK_OTHER\x10\x89\x02\x12\x15\n\x10\x42S_LOCALRECOVERY\x10\x8a\x02\x12\x10\n\x0b\x42S_HULLCOMP\x10\x8b\x02\x12\x10\n\x0b\x42S_HULLRECS\x10\x8c\x02\x12\x10\n\x0b\x42S_HULLHUGE\x10\x8d\x02\x12\x0f\n\nBS_SYNCLOG\x10\x8e\x02\x12\x0f\n\nBS_SYNCJOB\x10\x8f\x02\x12\x0e\n\tBS_SYNCER\x10\x90\x02\x12\x0c\n\x07\x42S_REPL\x10\x91\x02\x12\r\n\x08\x42S_PDISK\x10\x92\x02\x12\x12\n\rBS_PDISK_TEST\x10\xce\x08\x12\x0c\n\x07\x42S_YARD\x10\x93\x02\x12\r\n\x08\x42S_PROXY\x10\x94\x02\x12\x0c\n\x07\x42S_NODE\x10\x95\x02\x12\x12\n\rBS_CONTROLLER\x10\x96\x02\x12\x0e\n\tBS_DEVICE\x10\x97\x02\x12\x14\n\x0f\x42S_PDISK_SYSLOG\x10\x98\x02\x12\x13\n\x0e\x42S_PROXY_BLOCK\x10\x99\x02\x12\x15\n\x10\x42S_PROXY_COLLECT\x10\x9a\x02\x12\x16\n\x11\x42S_PROXY_DISCOVER\x10\x9b\x02\x12\x11\n\x0c\x42S_PROXY_GET\x10\x9c\x02\x12\x11\n\x0c\x42S_PROXY_PUT\x10\x9d\x02\x12\x13\n\x0e\x42S_PROXY_RANGE\x10\x9e\x02\x12\r\n\x08\x42S_QUEUE\x10\x9f\x02\x12\x16\n\x11\x42S_PROXY_MULTIGET\x10\xa0\x02\x12\x1a\n\x15\x42S_PROXY_MULTICOLLECT\x10\xa1\x02\x12\x18\n\x13\x42S_CONTROLLER_AUDIT\x10\xb0\x02\x12\x10\n\x0b\x42S_SELFHEAL\x10\xd6\x02\x12\x13\n\x0e\x42S_PROXY_PATCH\x10\xd7\x02\x12\x13\n\x0e\x42S_VDISK_SCRUB\x10\xd8\x02\x12\x13\n\x0e\x42S_VDISK_PATCH\x10\xd9\x02\x12\x14\n\x0f\x42S_VDISK_DEFRAG\x10\xda\x02\x12\x18\n\x13\x42S_PROXY_ASSIMILATE\x10\xdb\x02\x12\x11\n\x0cTX_DATASHARD\x10\xa2\x02\x12\x1d\n\x18\x42S_PROXY_INDEXRESTOREGET\x10\xa3\x02\x12\x14\n\x0f\x42S_PROXY_STATUS\x10\xa4\x02\x12\x11\n\x0c\x42S_LOAD_TEST\x10\xa5\x02\x12\x10\n\x0b\x42S_INCRHUGE\x10\xa6\x02\x12\x11\n\x0c\x42S_LOGCUTTER\x10\xa9\x02\x12\x14\n\x0f\x42S_VDISK_CHUNKS\x10\xab\x02\x12\x19\n\x14SCHEMESHARD_DESCRIBE\x10\xa7\x02\x12\x18\n\x13\x46LAT_TX_SCHEMESHARD\x10\xa8\x02\x12\x10\n\x0bSHEME_SHARD\x10\xbc\x05\x12\x11\n\x0cTX_OLAPSHARD\x10\xcb\x02\x12\x13\n\x0eTX_COLUMNSHARD\x10\xcc\x02\x12\x0f\n\nBLOB_CACHE\x10\xcd\x02\x12\x18\n\x13TX_COLUMNSHARD_SCAN\x10\xce\x02\x12\x0f\n\nBS_HANDOFF\x10\xaa\x02\x12\t\n\x04HIVE\x10\xac\x02\x12\n\n\x05LOCAL\x10\xad\x02\x12\x11\n\x0c\x42OOTSTRAPPER\x10\xae\x02\x12\x10\n\x0bTENANT_POOL\x10\xaf\x02\x12\x16\n\x11LABELS_MAINTAINER\x10\xb1\x02\x12\x14\n\x0fTABLET_EXECUTOR\x10\xb6\x02\x12\x10\n\x0bTABLET_MAIN\x10\xb7\x02\x12\x14\n\x0fTABLET_DATABASE\x10\xb8\x02\x12\x14\n\x0fTABLET_RESOLVER\x10\xb9\x02\x12\x18\n\x13TABLET_SAUSAGECACHE\x10\xba\x02\x12\x12\n\rTABLET_FLATEX\x10\xbb\x02\x12\x14\n\x0fTABLET_FLATBOOT\x10\xbc\x02\x12\x16\n\x11TABLET_AGGREGATOR\x10\xbd\x02\x12\x14\n\x0fTABLET_OPS_HOST\x10\x9a\x05\x12\x10\n\x0bOPS_COMPACT\x10\x9b\x05\x12\x0f\n\nOPS_BACKUP\x10\x9c\x05\x12\x10\n\x0bSAUSAGE_BIO\x10\x9d\x05\x12\r\n\x08\x46\x41KE_ENV\x10\x9e\x05\x12\x10\n\x0bPIPE_CLIENT\x10\xc0\x02\x12\x10\n\x0bPIPE_SERVER\x10\xc1\x02\x12\r\n\x08TX_DUMMY\x10\xca\x02\x12\x13\n\x0eMINIKQL_ENGINE\x10\xd4\x02\x12\x15\n\x10KQP_TASKS_RUNNER\x10\xd5\x02\x12\x0e\n\tJOBRUNNER\x10\xde\x02\x12\x14\n\x0fJOBRUNNER_PROXY\x10\xdf\x02\x12\x19\n\x14JOBRUNNER_CONTRACTOR\x10\xe0\x02\x12\x15\n\x10JOB_POOL_MANAGER\x10\xe1\x02\x12 \n\x1b\x46LAT_JOBRUNNER_POOL_MANAGER\x10\xe2\x02\x12\x16\n\x11\x45XECUTION_SERVICE\x10\xe8\x02\x12\x1c\n\x17\x45XECUTION_SERVICE_PROXY\x10\xe9\x02\x12\x11\n\x0cKWCALC_PROXY\x10\xea\x02\x12\x18\n\x13KWCALC_PROXY_WORKER\x10\xeb\x02\x12\x12\n\rYQL_EXECUTION\x10\xec\x02\x12\x0f\n\nYAMR_PROXY\x10\xed\x02\x12\x15\n\x10YQL_KIKIMR_PROXY\x10\xee\x02\x12\x0c\n\x07TRIGGER\x10\xf2\x02\x12\x13\n\x0eTX_COORDINATOR\x10\xfc\x02\x12\x1b\n\x16TX_COORDINATOR_PRIVATE\x10\xfd\x02\x12\"\n\x1dTX_COORDINATOR_MEDIATOR_QUEUE\x10\xfe\x02\x12\x10\n\x0bTX_MEDIATOR\x10\x86\x03\x12\x18\n\x13TX_MEDIATOR_PRIVATE\x10\x87\x03\x12\x1b\n\x16TX_MEDIATOR_EXEC_QUEUE\x10\x88\x03\x12\x1c\n\x17TX_MEDIATOR_TABLETQUEUE\x10\x89\x03\x12\x19\n\x14TX_MEDIATOR_TIMECAST\x10\x8a\x03\x12\r\n\x08TX_PROXY\x10\x90\x03\x12\x1a\n\x15TX_PROXY_SCHEME_CACHE\x10\x91\x03\x12\x11\n\x0cMSGBUS_PROXY\x10\x93\x03\x12\x11\n\x0cTX_ALLOCATOR\x10\x92\x03\x12\x18\n\x13TX_ALLOCATOR_CLIENT\x10\x94\x03\x12\x14\n\x0fLONG_TX_SERVICE\x10\x95\x03\x12\x0b\n\x06LOGGER\x10\x9a\x03\x12\x12\n\rMSGBUS_TRACER\x10\x9b\x03\x12\x13\n\x0eMSGBUS_REQUEST\x10\x9c\x03\x12\x10\n\x0bGRPC_SERVER\x10\x9d\x03\x12\x0f\n\nGRPC_PROXY\x10\x9f\x03\x12!\n\x1cGRPC_PROXY_NO_CONNECT_ACCESS\x10\xa1\x03\x12\x13\n\x0eREAD_TABLE_API\x10\x9e\x03\x12\x10\n\x0bRPC_REQUEST\x10\xa0\x03\x12\r\n\x08KEYVALUE\x10\xa4\x03\x12\x10\n\x0bKEYVALUE_GC\x10\xa5\x03\x12\x0b\n\x06WILSON\x10\xae\x03\x12\x0e\n\tPERSQUEUE\x10\xb8\x03\x12\x11\n\x0cPQ_METACACHE\x10\xb9\x03\x12\x12\n\rPQ_READ_PROXY\x10\xba\x03\x12\x13\n\x0ePQ_WRITE_PROXY\x10\xbb\x03\x12\x10\n\x0bPQ_MIRRORER\x10\xbe\x03\x12\x1a\n\x15PQ_READ_SPEED_LIMITER\x10\xbf\x03\x12\x1c\n\x17PERSQUEUE_READ_BALANCER\x10\xc0\x03\x12\x12\n\rPQ_MOVE_TOPIC\x10\xc1\x03\x12\x11\n\x0c\x43HOOSE_PROXY\x10\xbc\x03\x12\x16\n\x11LB_CONFIG_MANAGER\x10\xbd\x03\x12\x12\n\rTOKEN_BUILDER\x10\xc2\x03\x12\x12\n\rTICKET_PARSER\x10\xc7\x03\x12\x17\n\x12\x42LACKBOX_VALIDATOR\x10\xcc\x03\x12\x10\n\x0bGRPC_CLIENT\x10\xcd\x03\x12\x08\n\x03SQS\x10\xd6\x03\x12\x12\n\rBOARD_REPLICA\x10\xe0\x03\x12\x11\n\x0c\x42OARD_LOOKUP\x10\xe1\x03\x12\x12\n\rBOARD_PUBLISH\x10\xe2\x03\x12\x13\n\x0eQUOTER_SERVICE\x10\xea\x03\x12\x11\n\x0cQUOTER_PROXY\x10\xeb\x03\x12\x0b\n\x06HEALTH\x10\xf4\x03\x12\x14\n\x0fMEMORY_PROFILER\x10\xfe\x03\x12\x15\n\x10\x44\x41TASHARD_BACKUP\x10\x8a\x04\x12\x08\n\x03\x43MS\x10\x8b\x04\x12\x0f\n\nHTTP_PROXY\x10\x8c\x04\x12\x10\n\x0bNODE_BROKER\x10\x8d\x04\x12\x17\n\x12TENANT_SLOT_BROKER\x10\x8e\x04\x12\x10\n\x0b\x43MS_TENANTS\x10\x8f\x04\x12\x10\n\x0b\x43MS_CONFIGS\x10\x90\x04\x12\x10\n\x0b\x43MS_CLUSTER\x10\x91\x04\x12\x0e\n\tKQP_PROXY\x10\x92\x04\x12\x0f\n\nKQP_WORKER\x10\x93\x04\x12\x10\n\x0bKQP_GATEWAY\x10\x94\x04\x12\x0c\n\x07KQP_YQL\x10\x95\x04\x12\x11\n\x0cKQP_EXECUTER\x10\x96\x04\x12\x10\n\x0bKQP_COMPUTE\x10\x97\x04\x12\x11\n\x0cKQP_SLOW_LOG\x10\x98\x04\x12\x18\n\x13KQP_COMPILE_SERVICE\x10\x99\x04\x12\x16\n\x11KQP_COMPILE_ACTOR\x10\x9a\x04\x12\x19\n\x14KQP_RESOURCE_MANAGER\x10\x9b\x04\x12\x16\n\x11KQP_BLOBS_STORAGE\x10\x9d\x04\x12\x18\n\x13KQP_COMPILE_REQUEST\x10\x9e\x04\x12\r\n\x08KQP_NODE\x10\x9f\x04\x12\x12\n\rKQP_LOAD_TEST\x10\xa0\x04\x12\x10\n\x0bKQP_SESSION\x10\xa1\x04\x12\x1b\n\x16TABLET_RESOURCE_BROKER\x10\x9c\x04\x12\x10\n\x0bKESUS_PROXY\x10\xa6\x04\x12\x18\n\x13KESUS_PROXY_SERVICE\x10\xa7\x04\x12\x18\n\x13KESYS_PROXY_REQUEST\x10\xa8\x04\x12\x11\n\x0cKESUS_TABLET\x10\xa9\x04\x12\x17\n\x12\x43ONFIGS_DISPATCHER\x10\xb0\x04\x12\x12\n\rCONFIGS_CACHE\x10\xb1\x04\x12\x19\n\x14SCHEME_BOARD_REPLICA\x10\xba\x04\x12\x1c\n\x17SCHEME_BOARD_SUBSCRIBER\x10\xbb\x04\x12\x1b\n\x16SCHEME_BOARD_POPULATOR\x10\xbc\x04\x12\x16\n\x11\x44S_PROXY_NODE_MON\x10\xd8\x04\x12\x0f\n\nTEST_SHARD\x10\xd9\x04\x12\x12\n\rSEQUENCESHARD\x10\xda\x04\x12\x12\n\rSEQUENCEPROXY\x10\xdb\x04\x12\x13\n\x0eYF_JOB_SERVICE\x10\xbd\x05\x12\x12\n\rYF_JOB_RUNNER\x10\xbe\x05\x12\x11\n\x0cYF_JOB_AGENT\x10\xbf\x05\x12\x0f\n\nYF_GATEWAY\x10\xc0\x05\x12\x17\n\x12YF_GATEWAY_SERVICE\x10\xc1\x05\x12\x0f\n\nYF_SERVICE\x10\xc2\x05\x12\x13\n\x0eYF_MON_SERVICE\x10\xc3\x05\x12\x15\n\x10YF_CALL_BALANCER\x10\xc4\x05\x12\x1c\n\x17YF_DESCRIPTIONS_SERVICE\x10\xc5\x05\x12\x0e\n\tYF_WORKER\x10\xc6\x05\x12\x13\n\x0eNET_CLASSIFIER\x10\xc7\x05\x12\x1e\n\x19PERSQUEUE_CLUSTER_TRACKER\x10\xc8\x05\x12\x0e\n\tYQL_PROXY\x10\xc9\x05\x12\x16\n\x11YQL_PRIVATE_PROXY\x10\xca\x05\x12\x16\n\x11YQL_NODES_MANAGER\x10\xcb\x05\x12\x1a\n\x15YANDEX_CLOUD_FUNCTION\x10\xcc\x05\x12\x0b\n\x06\x45XPORT\x10\xa0\x06\x12\x16\n\x11\x44\x41TASHARD_RESTORE\x10\xa1\x06\x12\x0b\n\x06IMPORT\x10\xa2\x06\x12\x0f\n\nS3_WRAPPER\x10\xa3\x06\x12\x11\n\x0cSYSTEM_VIEWS\x10\x84\x07\x12\x10\n\x0b\x42UILD_INDEX\x10\xe8\x07\x12\x15\n\x10\x41UDIT_LOG_WRITER\x10\xed\x07\x12\x14\n\x0fMETERING_WRITER\x10\xf2\x07\x12\x0c\n\x07STREAMS\x10\xf3\x07\x12\x14\n\x0fSTREAMS_SERVICE\x10\xf4\x07\x12\x1c\n\x17STREAMS_STORAGE_SERVICE\x10\xf5\x07\x12\x1e\n\x19STREAMS_SCHEDULER_SERVICE\x10\xf6\x07\x12\x1d\n\x18STREAMS_RESOURCE_SERVICE\x10\xf7\x07\x12#\n\x1eSTREAMS_CHECKPOINT_COORDINATOR\x10\xf8\x07\x12\"\n\x1dSTREAMS_CONTROL_PLANE_SERVICE\x10\xf9\x07\x12!\n\x1cSTREAMS_GRAND_LEADER_SERVICE\x10\xfa\x07\x12!\n\x1cSTREAMS_META_STORAGE_SERVICE\x10\xfb\x07\x12\x19\n\x14STREAMS_GRAPH_LEADER\x10\xfc\x07\x12\x1d\n\x18YQ_CONTROL_PLANE_STORAGE\x10\xfd\x07\x12\x1b\n\x16YQ_CONTROL_PLANE_PROXY\x10\xfe\x07\x12\x17\n\x12YQ_TEST_CONNECTION\x10\xff\x07\x12\r\n\x08YQ_AUDIT\x10\xfe\x08\x12\x1a\n\x15YQ_AUDIT_EVENT_SENDER\x10\xff\x08\x12\x0e\n\tYQ_HEALTH\x10\x80\t\x12\x18\n\x13\x46Q_INTERNAL_SERVICE\x10\x81\t\x12\x15\n\x10\x46Q_QUOTA_SERVICE\x10\x82\t\x12\x14\n\x0fYQ_RATE_LIMITER\x10\x83\t\x12\x13\n\x0e\x46Q_QUOTA_PROXY\x10\x84\t\x12\x10\n\x0bPUBLIC_HTTP\x10\x85\t\x12\x1c\n\x17\x46Q_CONTROL_PLANE_CONFIG\x10\x86\t\x12\x11\n\x0c\x46Q_RUN_ACTOR\x10\x87\t\x12\x19\n\x14\x46Q_DATABASE_RESOLVER\x10\x88\t\x12\x17\n\x12\x46Q_PENDING_FETCHER\x10\x89\t\x12\x0e\n\tFQ_PINGER\x10\x8a\t\x12\x15\n\x10\x46Q_RESULT_WRITER\x10\x8b\t\x12\x13\n\x0e\x46Q_LOG_UPDATER\x10\x8c\t\x12\x13\n\x0e\x44Q_TASK_RUNNER\x10\x8d\t\x12\x0b\n\x06VIEWER\x10\x8e\t\x12\x14\n\x0f\x43HANGE_EXCHANGE\x10\xcc\x08\x12\x0c\n\x07YDB_SDK\x10\xcd\x08\x12\x1b\n\x16REPLICATION_CONTROLLER\x10\xb0\t\x12\x0f\n\nBLOB_DEPOT\x10\x94\n\x12\x15\n\x10\x42LOB_DEPOT_AGENT\x10\x95\n\x12\x16\n\x11\x42LOB_DEPOT_EVENTS\x10\x96\n\x12\x11\n\x0c\x44S_LOAD_TEST\x10\xf8\n\x12\x16\n\x11METADATA_PROVIDER\x10\xdc\x0b\x12\x19\n\x14METADATA_INITIALIZER\x10\xdd\x0b\x12\x15\n\x10METADATA_MANAGER\x10\xde\x0b\x12\x14\n\x0fMETADATA_SECRET\x10\xdf\x0b\x12\x0f\n\nTX_TIERING\x10\xc0\x0c\x12\r\n\x08\x42G_TASKS\x10\xa4\rB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.services_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _ESERVICEKIKIMR._serialized_start=17087
  _ESERVICEKIKIMR._serialized_end=22266
  _TACTIVITY._serialized_start=53
  _TACTIVITY._serialized_end=17084
  _TACTIVITY_ETYPE._serialized_start=68
  _TACTIVITY_ETYPE._serialized_end=17084
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/test_shard.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n ydb/core/protos/test_shard.proto\x12\nNTestShard\"\x90\x07\n\x0cTStateServer\x1a\xb3\x01\n\x06TWrite\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12\x12\n\nGeneration\x18\x02 \x01(\r\x12\x0b\n\x03Key\x18\x03 \x01(\t\x12:\n\x0bOriginState\x18\x04 \x01(\x0e\x32%.NTestShard.TStateServer.EEntityState\x12:\n\x0bTargetState\x18\x05 \x01(\x0e\x32%.NTestShard.TStateServer.EEntityState\x1a@\n\x0cTWriteResult\x12\x30\n\x06Status\x18\x01 \x01(\x0e\x32 .NTestShard.TStateServer.EStatus\x1a=\n\x05TRead\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12\x12\n\nGeneration\x18\x02 \x01(\r\x12\x0e\n\x06\x43ookie\x18\x03 \x01(\x0c\x1a\xd6\x01\n\x0bTReadResult\x12\x30\n\x06Status\x18\x01 \x01(\x0e\x32 .NTestShard.TStateServer.EStatus\x12\x0e\n\x06\x43ookie\x18\x02 \x01(\x0c\x12\x39\n\x05Items\x18\x03 \x03(\x0b\x32*.NTestShard.TStateServer.TReadResult.TItem\x1aJ\n\x05TItem\x12\x0b\n\x03Key\x18\x01 \x01(\t\x12\x34\n\x05State\x18\x02 \x01(\x0e\x32%.NTestShard.TStateServer.EEntityState\x1a\x33\n\x0bTTabletInfo\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12\x12\n\nGeneration\x18\x02 \x01(\r\x1a\xb3\x01\n\x08TRequest\x12\x30\n\x05Write\x18\x01 \x01(\x0b\x32\x1f.NTestShard.TStateServer.TWriteH\x00\x12.\n\x04Read\x18\x02 \x01(\x0b\x32\x1e.NTestShard.TStateServer.TReadH\x00\x12:\n\nTabletInfo\x18\x03 \x01(\x0b\x32$.NTestShard.TStateServer.TTabletInfoH\x00\x42\t\n\x07\x43ommand\"]\n\x0c\x45\x45ntityState\x12\n\n\x06\x41\x42SENT\x10\x00\x12\x11\n\rWRITE_PENDING\x10\x01\x12\r\n\tCONFIRMED\x10\x02\x12\x12\n\x0e\x44\x45LETE_PENDING\x10\x03\x12\x0b\n\x07\x44\x45LETED\x10\x04\"&\n\x07\x45Status\x12\x06\n\x02OK\x10\x00\x12\t\n\x05\x45RROR\x10\x01\x12\x08\n\x04RACE\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.test_shard_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TSTATESERVER._serialized_start=49
  _TSTATESERVER._serialized_end=961
  _TSTATESERVER_TWRITE._serialized_start=66
  _TSTATESERVER_TWRITE._serialized_end=245
  _TSTATESERVER_TWRITERESULT._serialized_start=247
  _TSTATESERVER_TWRITERESULT._serialized_end=311
  _TSTATESERVER_TREAD._serialized_start=313
  _TSTATESERVER_TREAD._serialized_end=374
  _TSTATESERVER_TREADRESULT._serialized_start=377
  _TSTATESERVER_TREADRESULT._serialized_end=591
  _TSTATESERVER_TREADRESULT_TITEM._serialized_start=517
  _TSTATESERVER_TREADRESULT_TITEM._serialized_end=591
  _TSTATESERVER_TTABLETINFO._serialized_start=593
  _TSTATESERVER_TTABLETINFO._serialized_end=644
  _TSTATESERVER_TREQUEST._serialized_start=647
  _TSTATESERVER_TREQUEST._serialized_end=826
  _TSTATESERVER_EENTITYSTATE._serialized_start=828
  _TSTATESERVER_EENTITYSTATE._serialized_end=921
  _TSTATESERVER_ESTATUS._serialized_start=923
  _TSTATESERVER_ESTATUS._serialized_end=961
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/tablet_database.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import base_pb2 as ydb_dot_core_dot_protos_dot_base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%ydb/core/protos/tablet_database.proto\x12\rNKikimrTablet\x1a\x1aydb/core/protos/base.proto\"\x80\t\n\x11TExecutorSettings\x12H\n\x0e\x44\x61tabasePolicy\x18\x01 \x01(\x0b\x32\x30.NKikimrTablet.TExecutorSettings.TDatabasePolicy\x12J\n\x0fRuntimeSettings\x18\x02 \x01(\x0b\x32\x31.NKikimrTablet.TExecutorSettings.TRuntimeSettings\x1a\x96\x01\n\x14TLocalityGroupPolicy\x12\x17\n\x0fLocalityGroupId\x18\x01 \x01(\r\x12\x19\n\x11MaxChunkSizeBytes\x18\x02 \x01(\r\x12\x18\n\x10MaxBlobSizeBytes\x18\x03 \x01(\r\x12\x1a\n\x12TabletChannelIndex\x18\x04 \x01(\r\x12\x14\n\x0cKeepInMemory\x18\x05 \x01(\x08\x1a\x97\x04\n\x11TCompactionPolicy\x12\x1b\n\x13InMemSizeToSnapshot\x18\x01 \x01(\x04\x12\x1c\n\x14InMemStepsToSnapshot\x18\x02 \x01(\r\x12!\n\x19InMemForceStepsToSnapshot\x18\x03 \x01(\r\x12 \n\x18InMemForceSizeToSnapshot\x18\x04 \x01(\x04\x12 \n\x18InMemForceTimeToSnapshot\x18\x05 \x01(\x04\x12\x1c\n\x14InMemCompactionQueue\x18\x06 \x01(\r\x12X\n\nGeneration\x18\n \x03(\x0b\x32\x44.NKikimrTablet.TExecutorSettings.TCompactionPolicy.TGenerationPolicy\x1a\xe7\x01\n\x11TGenerationPolicy\x12\x14\n\x0cGenerationId\x18\x01 \x01(\r\x12\x15\n\rSizeToCompact\x18\x02 \x01(\x04\x12\x16\n\x0e\x43ountToCompact\x18\x03 \x01(\r\x12\x1a\n\x12TimeFromCompaction\x18\x04 \x01(\x04\x12\x1b\n\x13\x46orceCountToCompact\x18\n \x01(\r\x12\x1a\n\x12\x46orceSizeToCompact\x18\x0b \x01(\x04\x12\x1f\n\x17\x46orceTimeFromCompaction\x18\x0c \x01(\x04\x12\x17\n\x0f\x43ompactionQueue\x18\x14 \x01(\r\x1a\x8d\x02\n\x0fTDatabasePolicy\x12\x15\n\rMainCacheSize\x18\x01 \x01(\x04\x12\x17\n\x0f\x45xecutorTxInFly\x18\x02 \x01(\r\x12\"\n\x1aTabletMetaInfoChannelIndex\x18\x03 \x01(\r\x12L\n\x10\x43ompactionPolicy\x18\n \x01(\x0b\x32\x32.NKikimrTablet.TExecutorSettings.TCompactionPolicy\x12R\n\x13LocalityGroupPolicy\x18\x0b \x03(\x0b\x32\x35.NKikimrTablet.TExecutorSettings.TLocalityGroupPolicyJ\x04\x08\x64\x10\x65\x1a\x12\n\x10TRuntimeSettings\"}\n\x11TCompactionBroker\x12:\n\x05Queue\x18\x01 \x03(\x0b\x32+.NKikimrTablet.TCompactionBroker.TQueueType\x1a,\n\nTQueueType\x12\x0f\n\x07QueueID\x18\x01 \x01(\r\x12\r\n\x05Quota\x18\x02 \x01(\r\"P\n\x1cTEvSetCompactionBrokerConfig\x12\x30\n\x06\x43onfig\x18\x01 \x01(\x0b\x32 .NKikimrTablet.TCompactionBroker\"`\n\"TEvSetCompactionBrokerConfigResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x0e\n\x06Reason\x18\x02 \x01(\x0c\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.tablet_database_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TEXECUTORSETTINGS._serialized_start=85
  _TEXECUTORSETTINGS._serialized_end=1237
  _TEXECUTORSETTINGS_TLOCALITYGROUPPOLICY._serialized_start=257
  _TEXECUTORSETTINGS_TLOCALITYGROUPPOLICY._serialized_end=407
  _TEXECUTORSETTINGS_TCOMPACTIONPOLICY._serialized_start=410
  _TEXECUTORSETTINGS_TCOMPACTIONPOLICY._serialized_end=945
  _TEXECUTORSETTINGS_TCOMPACTIONPOLICY_TGENERATIONPOLICY._serialized_start=714
  _TEXECUTORSETTINGS_TCOMPACTIONPOLICY_TGENERATIONPOLICY._serialized_end=945
  _TEXECUTORSETTINGS_TDATABASEPOLICY._serialized_start=948
  _TEXECUTORSETTINGS_TDATABASEPOLICY._serialized_end=1217
  _TEXECUTORSETTINGS_TRUNTIMESETTINGS._serialized_start=1219
  _TEXECUTORSETTINGS_TRUNTIMESETTINGS._serialized_end=1237
  _TCOMPACTIONBROKER._serialized_start=1239
  _TCOMPACTIONBROKER._serialized_end=1364
  _TCOMPACTIONBROKER_TQUEUETYPE._serialized_start=1320
  _TCOMPACTIONBROKER_TQUEUETYPE._serialized_end=1364
  _TEVSETCOMPACTIONBROKERCONFIG._serialized_start=1366
  _TEVSETCOMPACTIONBROKERCONFIG._serialized_end=1446
  _TEVSETCOMPACTIONBROKERCONFIGRESULT._serialized_start=1448
  _TEVSETCOMPACTIONBROKERCONFIGRESULT._serialized_end=1544
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/grpc_status_proxy.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'ydb/core/protos/grpc_status_proxy.proto\x12\x10NKikimrGRpcProxy\"\x15\n\x13TEvGetStatusRequest\"&\n\x14TEvGetStatusResponse\x12\x0e\n\x06Weight\x18\x01 \x01(\x04\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.grpc_status_proxy_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TEVGETSTATUSREQUEST._serialized_start=61
  _TEVGETSTATUSREQUEST._serialized_end=82
  _TEVGETSTATUSRESPONSE._serialized_start=84
  _TEVGETSTATUSRESPONSE._serialized_end=122
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/yq/libs/config/protos/read_actors_factory.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.library.yql.providers.s3.proto import retry_config_pb2 as ydb_dot_library_dot_yql_dot_providers_dot_s3_dot_proto_dot_retry__config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8ydb/core/yq/libs/config/protos/read_actors_factory.proto\x12\x0bNYq.NConfig\x1a\x35ydb/library/yql/providers/s3/proto/retry_config.proto\"\x88\x01\n\x19TS3ReadActorFactoryConfig\x12+\n\x0bRetryConfig\x18\x01 \x01(\x0b\x32\x16.NYql.NS3.TRetryConfig\x12\x13\n\x0bRowsInBatch\x18\x02 \x01(\x04\x12\x13\n\x0bMaxInflight\x18\x03 \x01(\x04\x12\x14\n\x0c\x44\x61taInflight\x18\x04 \x01(\x04\"5\n\x19TPqReadActorFactoryConfig\x12\x18\n\x10\x43ookieCommitMode\x18\x01 \x01(\x08\"\xae\x01\n\x18TReadActorsFactoryConfig\x12H\n\x18S3ReadActorFactoryConfig\x18\x01 \x01(\x0b\x32&.NYq.NConfig.TS3ReadActorFactoryConfig\x12H\n\x18PqReadActorFactoryConfig\x18\x02 \x01(\x0b\x32&.NYq.NConfig.TPqReadActorFactoryConfigB\x1b\n\x16ru.yandex.kikimr.proto\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.yq.libs.config.protos.read_actors_factory_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\370\001\001'
  _TS3READACTORFACTORYCONFIG._serialized_start=129
  _TS3READACTORFACTORYCONFIG._serialized_end=265
  _TPQREADACTORFACTORYCONFIG._serialized_start=267
  _TPQREADACTORFACTORYCONFIG._serialized_end=320
  _TREADACTORSFACTORYCONFIG._serialized_start=323
  _TREADACTORSFACTORYCONFIG._serialized_end=497
# @@protoc_insertion_point(module_scope)
